const { defineConfig } = require('eslint-define-config');

module.exports = defineConfig({
  root: true,
  env: {
    node: true,
    browser: true,
  },
  parser: 'vue-eslint-parser',
  parserOptions: {
    parser: require.resolve('@typescript-eslint/parser'),
    extraFileExtensions: ['.vue'],
    ecmaFeatures: {
      jsx: true,
      tsx: true,
    },
  },
  extends: [
    'plugin:@typescript-eslint/eslint-recommended',
    'plugin:vue/vue3-recommended',
    'prettier',
    '@vue/prettier',
    '@smart/typescript',
  ],
  rules: {
    'no-plusplus': 'off',
    '@typescript-eslint/no-unused-vars': [2, { 'args': 'none' }],
    'no-param-reassign': 'off',
    'semi': ['warn', 'always'],
    'indent': [
      'warn',
      2,
      {
        'SwitchCase': 1,
        'ignoredNodes': ['VariableDeclaration[declarations.length=0]']
      }
    ],

    'import/no-relative-packages': 'off',
    'arrow-parens': ['error', 'always', { 'requireForBlockBody': true }],

    '@typescript-eslint/consistent-type-imports': [
      'error',
      { disallowTypeAnnotations: false },
    ],

    // vue
    'vue/html-self-closing': [
      'error',
      {
        html: {
          void: 'any',
          normal: 'never',
          component: 'always',
        },
        svg: 'always',
        math: 'always',
      },
    ],
    'vue/max-attributes-per-line': [
      'error',
      {
        singleline: {
          max: 4,
          allowFirstLine: true,
        },
        multiline: {
          max: 1,
          allowFirstLine: true,
        },
      },
    ],
    'vue/require-default-prop': 'off',
    'import/no-extraneous-dependencies': 'off',
    'camelcase': 'off',
    '@typescript-eslint/camelcase': 0,
  },
  globals: {
    defineProps: 'readonly',
    defineEmits: 'readonly',
    defineExpose: 'readonly',
    withDefaults: 'readonly',
  },
});
