/* eslint-disable camelcase */
import type { AxiosResponse } from 'axios';
import qs from 'qs';
import request from '@/utils/request';

export interface loginData {
  grant_type: string;
  username: string;
  password: string;
  ver_key?: string | undefined;
  ver_code?: string;
}

/**
 * @description 获取菜单数组
 */
export function getRouterList(): Promise<AxiosResponse> {
  return request({
    url: '/system/menu/navigatePerMenuList',
    method: 'get',
  });
}

/**
 * @description 获取菜单树
 */
export function getRouterTree(): Promise<AxiosResponse> {
  return request({
    url: '/system/menu/navigatePerMenu',
    method: 'get',
  });
}

/**
 * @description 获取验证码
 */
export function getCaptcha(): Promise<AxiosResponse> {
  return request({
    url: '/system/login/captcha',
    method: 'get',
  });
}

/**
 * @description 登录
 */
export function onLogin(data: loginData): Promise<AxiosResponse> {
  return request({
    url: '/auth/oauth/token',
    method: 'post',
    data: qs.stringify(data),
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
  });
}

/**
 * @description 退出登录
 */
export function userLogout(): Promise<AxiosResponse> {
  return request({
    url: '/system/user/userLogout',
    method: 'post',
  });
}

/**
 * 修改用户密码
 */
export function updateUserPassword(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/user/updateUserPassword',
    method: 'post',
    data,
  });
}

/**
 * 根据token获取用户信息
 */
export function selectUserByToken(): Promise<AxiosResponse> {
  return request({
    url: '/system/user/selectUserByToken',
    method: 'get',
  });
}

/**
 * 个人信息-需改用户
 */
export function updateBySelf(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/user/updateBySelf',
    method: 'post',
    data,
  });
}

/**
 * 上传文件
 */
export const uploadFile = (data = {}): Promise<AxiosResponse> =>
  request({
    url: '/system/file/avatar',
    method: 'post',
    data,
  });

/**
 * 轮询接口
 * */
export const pollOfflineStatus = (data: { loginId: string }): Promise<AxiosResponse> =>
  request({
    url: 'system/login/pollOfflineStatus',
    method: 'get',
    params: data,
  });

/**
 * 同意下线接口
 */
export const agreeOffline = (): Promise<AxiosResponse> =>
  request({
    url: 'system/user/agreeOffline',
    method: 'get',
  });

/**
 * 拒绝下线接口
 */
export const refuseOffline = (): Promise<AxiosResponse> =>
  request({
    url: 'system/user/refuseOffline',
    method: 'get',
  });

export const refreshToken = () => {
  const token = localStorage.getItem('TOKEN');
  let refreshToken = '';
  if (token && token !== 'undefined') {
    refreshToken = JSON.parse(token).refresh_token;
  }
  const params = {
    client_id: 'lin',
    client_secret: '123123',
    grant_type: 'refresh_token',
    refresh_token: refreshToken,
  };
  return request({
    url: '/auth/oauth/token',
    method: 'post',
    data: qs.stringify(params),
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
  });
};
