import type { AxiosResponse } from 'axios';
import type { BlobData } from '@/types/tools';
import request from '@/utils/request';

/**
 * @description 树状组织架构列表(分页)
 */
export function getOrganize(data: unknown): Promise<AxiosResponse> {
  return request({
    url: '/system/org/tree',
    method: 'get',
    params: data,
  });
}

/**
 * @description 树状组织架构列表(不分页)
 */
export function getOrgAll(): Promise<AxiosResponse> {
  return request({
    url: '/system/org/tree/all',
    method: 'get',
  });
}

/**
 * @description 添加组织信息
 */
export function addOrganize(data: unknown): Promise<AxiosResponse> {
  return request({
    url: '/system/org',
    method: 'post',
    data,
  });
}

/**
 * @description 修改组织信息
 */
export function updateOrganize(data: unknown): Promise<AxiosResponse> {
  return request({
    url: '/system/org/update',
    method: 'post',
    data,
  });
}

/**
 * @description 根据id数组删除组织信息
 */
export function deleteOrganize(data: unknown): Promise<AxiosResponse> {
  return request({
    url: '/system/org/delete',
    method: 'post',
    data,
  });
}

/**
 * @description 导出数据
 */
export function getFile(): Promise<AxiosResponse<BlobData>> {
  return request({
    url: '/system/org/export',
    method: 'get',
    responseType: 'blob',
  });
}

/**
 * @description 获取树状行政区域列表
 */
export function getDistrict(): Promise<AxiosResponse> {
  return request({
    url: '/system/district/tree',
    method: 'get',
  });
}

/**
 * @description 判断当前组织是否能删除
 */
export function isOrgHasChildren(data: unknown): Promise<AxiosResponse> {
  return request({
    method: 'post',
    url: '/system/org/existChildren',
    data,
  });
}

/**
 * @description 查询组织负责人
 */
export function getOrgDirector(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/org/getOrgDirector',
    method: 'get',
    params: data,
  });
}

/**
 * @description 获取用户列表下拉值
 */
export function getUserListByOrgId(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/org/getUserListByOrgId',
    method: 'get',
    params: data,
  });
}
