import type { AxiosResponse } from 'axios';
import type { BlobData } from '@/types/tools';
import request from '@/utils/request';

/**
 * @description 岗位类型列表
 */
export function getPostList(): Promise<AxiosResponse> {
  return request({
    url: '/system/position/list',
    method: 'get',
  });
}

/**
 * @description 分页查询岗位信息
 */
export function getPostPage(data: any): Promise<AxiosResponse> {
  return request({
    url: '/system/position/page',
    method: 'get',
    params: data,
  });
}

/**
 * @description 添加岗位
 */
export function addPost(data: unknown): Promise<AxiosResponse> {
  return request({
    url: '/system/position',
    method: 'post',
    data,
  });
}

/**
 * @description 修改岗位
 */
export function editPost(data: unknown): Promise<AxiosResponse> {
  return request({
    url: '/system/position/update',
    method: 'post',
    data,
  });
}

/**
 * @description 删除岗位
 */
export function deletePost(data: unknown): Promise<AxiosResponse> {
  return request({
    url: '/system/position/delete',
    method: 'post',
    data,
  });
}

/**
 * @description 岗位禁用或启用
 */
export function disableOrEnable(data: unknown): Promise<AxiosResponse> {
  return request({
    url: '/system/position/disableOrEnable',
    method: 'post',
    data,
  });
}

/**
 * @description 导出数据
 */
export function getFile(): Promise<AxiosResponse<BlobData>> {
  return request({
    url: '/system/position/export',
    method: 'get',
    responseType: 'blob',
  });
}

/**
 * @description 岗位数据导入
 */
export function importExcel(data: unknown): Promise<AxiosResponse> {
  return request({
    url: '/system/position/importExcel',
    method: 'post',
    data,
    headers: {
      'Content-Type': 'multipart/form-data;boundary=<calculated when request is sent>',
    },
  });
}

/**
 * @description 根据岗位id获取该岗位可选用户及已选用户信息
 */
export function getUserInfoByPositionId(
  data: { positionId: string } = { positionId: '' },
): Promise<AxiosResponse> {
  return request({
    url: `/system/position/user/${data.positionId}`,
    method: 'get',
  });
}

/**
 * @description 岗位新增关联用户
 */
export function addUserToPosition(data: any): Promise<AxiosResponse> {
  return request({
    url: '/system/position/addUserToPos',
    method: 'post',
    data,
  });
}

/**
 * @description 岗位移除关联用户
 */
export function removeUserFromPosition(data: any): Promise<AxiosResponse> {
  return request({
    url: '/system/position/removeUserFromPos',
    method: 'post',
    data,
  });
}
