import type { AxiosResponse } from 'axios';
import type { BlobData } from '@/types/tools';
import request from '@/utils/request';
import type { MenuTreeData } from '@/types/api/resourceManagement';

/**
 * @description 返回当前用户的树形菜单集合
 */
export function getMenu(): Promise<AxiosResponse<MenuTreeData>> {
  return request({
    url: '/system/menu/tree',
    method: 'get',
  });
}

/**
 * @description 导出数据
 */
export function getFile(): Promise<AxiosResponse<BlobData>> {
  return request({
    url: '/system/menu/export',
    method: 'get',
    responseType: 'blob',
  });
}

/**
 * @description 新增菜单
 */
export function addMenu(data: any): Promise<AxiosResponse> {
  return request({
    url: '/system/menu/save',
    method: 'post',
    data,
  });
}

/**
 * @description 修改菜单
 */
export function updateMenu(data: any): Promise<AxiosResponse> {
  return request({
    url: '/system/menu/update',
    method: 'post',
    data,
  });
}

/**
 * @description 修改系统资源菜单
 */
export function updateSystemMenu(data: any): Promise<AxiosResponse> {
  return request({
    url: 'system/menu/updateSystemMenu',
    method: 'post',
    data,
  });
}

/**
 * @description 删除菜单
 */
export function deleteMenu(data: any): Promise<AxiosResponse> {
  return request({
    url: '/system/menu/delete',
    method: 'post',
    data,
  });
}
