import type { AxiosResponse } from 'axios';
import type { BlobData } from '@/types/tools';
import request from '@/utils/request';

/**
 * @description 根据角色id获取资源树
 */
export function getRoleInfo(id: string): Promise<AxiosResponse> {
  return request({
    url: `/system/menu/getTreeMenusByRoleId/${id}`,
    method: 'get',
  });
}

/**
 * @description 添加角色
 */
export function addRole(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/role/save',
    method: 'post',
    data,
  });
}

/**
 * @description 修改角色
 */
export function editRole(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/role/update',
    method: 'post',
    data,
  });
}

/**
 * @description 删除角色
 */
export function deleteRole(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/role/delete',
    method: 'post',
    data,
  });
}

/**
 * @description 分页查询角色列表
 */
export function getRolePage(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/role/page',
    method: 'get',
    params: data,
  });
}

/**
 * @description 查询角色列表树
 */
export function getRoleTree(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/role/tree',
    method: 'get',
    params: data,
  });
}

/**
 * @description 获取全部角色列表
 */
export function getAllRole(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/role/all',
    method: 'get',
    params: data,
  });
}

/**
 * @description 角色关联权限菜单（单次操作）
 */
export function addMenu(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/role/roleAndMenu/add',
    method: 'post',
    data,
  });
}

/**
 * @description 删除角色关联权限菜单（单次操作）
 */
export function deleteMenu(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/role/roleAndMenu/delete',
    method: 'post',
    data,
  });
}

/**
 * @description 更新 角色 关联 权限菜单 批量操作(暂不使用)
 */
export function roleAndMenu(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/role/roleAndMenu/update',
    method: 'post',
    data,
  });
}

/**
 * @description 返回当前用户的树形菜单集合
 */
export function getMenu(): Promise<AxiosResponse> {
  return request({
    url: '/system/menu',
    method: 'get',
  });
}

/**
 * @description 根据角色id获取最底层资源信息列表
 */
export function getLowestMenus(id: string): Promise<AxiosResponse> {
  return request({
    url: `/system/menu/getLowestMenusByRoleId/${id}`,
    method: 'get',
  });
}

/**
 * @description 导出数据
 */
export function getFile(): Promise<AxiosResponse<BlobData>> {
  return request({
    url: '/system/role/export',
    method: 'get',
    responseType: 'blob',
  });
}

/**
 * @description 查询-角色已关联的用户
 */
export function getRoleUser(id: any): Promise<AxiosResponse> {
  return request({
    url: `/system/role/user/${id}`,
    method: 'get',
  });
}

/**
 * @description 角色新增用户
 */
export function addUserToRole(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/role/addUserToRole',
    method: 'post',
    data,
  });
}

/**
 * @description 删除角色已有的用户
 */
export function deleteUserToRole(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/role/removeUserFromRole',
    method: 'post',
    data,
  });
}

/**
 * @description 岗位数据导入
 */
export function importExcel(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/role/importExcel',
    method: 'post',
    data,
    headers: {
      'Content-Type': 'multipart/form-data;boundary=<calculated when request is sent>',
    },
  });
}

/**
 * @description 更新用户关联角色
 * @description @param data
 */
export function updateUserRole(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/user/userAndRole/update',
    method: 'post',
    data,
  });
}

/**
 * @description 更新角色关联资源
 */
export function updateRoleResource(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/role/roleAndMenu/update',
    method: 'post',
    data,
  });
}

/**
 * @description 更新角色，关联的用户
 * @description @param data
 */
export function updateUserToRole(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/role/updateUserToRole',
    method: 'post',
    data,
  });
}

/**
 * @description 查询角色/分组树（全部）
 */
export function getTreeRoleGroup(): Promise<AxiosResponse> {
  return request({
    url: 'system/role/selectTreeRoleGroup',
    method: 'get',
  });
}

/**
 * @description 查询组织-人员树
 */
export function getRecipient(data = {}): Promise<AxiosResponse> {
  return request({
    url: 'system/org/getRecipient',
    method: 'get',
    params: data,
  });
}

/**
 * @description 查询数据字典-类别-具体字典项
 * @description @param code
 */
export function getDictionaryTree(code: string): Promise<AxiosResponse> {
  return request({
    url: `/system/dict/item/info/${code}`,
    method: 'get',
  });
}

/**
 * @description 根据id查询角色信息
 * @description @param id
 */
export function getRoleDetail(id: string): Promise<AxiosResponse> {
  return request({
    url: `/system/role/${id}`,
    method: 'get',
  });
}

/**
 * @description 角色禁用或启用
 */
export function disableOrEnable(data: unknown): Promise<AxiosResponse> {
  return request({
    url: '/system/role/disableOrEnable',
    method: 'post',
    data,
  });
}

/**
 * @description 判断当前角色是否能删除
 */
export function hasRelatedUser(data: unknown): Promise<AxiosResponse> {
  return request({
    method: 'post',
    url: '/system/role/hasRelatedUser',
    data,
  });
}

/**
 * @description 查询-根据角色id查询可选资源和已选资源
 */
export function getRoleMenuTree(id: string): Promise<AxiosResponse> {
  return request({
    url: `/system/role/menu/${id}`,
    method: 'get',
  });
}

/**
 * @description 修改角色关联的菜单操作权限（0操作，1只读，2管理）
 */
export function updateMenuModify(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/role/roleAndMenu/modify',
    method: 'post',
    data,
  });
}
