import type { AxiosResponse } from 'axios';
import qs from 'qs';
import request from '@/utils/request';
import type { BlobData } from '@/types/tools';

/**
 * @description 分页获取用户列表
 */
export function getUserList(data: any): Promise<AxiosResponse> {
  return request({
    url: '/system/user/pageUser',
    method: 'get',
    params: data,
  });
}

/**
 * @description 通过ID查询用户信息
 */
export function getUserInfo(userId: string): Promise<AxiosResponse> {
  return request({
    url: `/system/user/${userId}`,
    method: 'get',
  });
}

/**
 * @description 添加用户
 */
export function addUser(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/user/saveUser',
    method: 'post',
    data,
  });
}

/**
 * @description 修改用户
 */
export function editUser(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/user/update',
    method: 'post',
    data,
  });
}

/**
 * @description 个人信息-需改用户
 */
export function updateBySelf(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/user/updateBySelf',
    method: 'post',
    data,
  });
}

/**
 * @description 删除用户
 */
export function deleteUser(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/user/delete',
    method: 'post',
    data,
  });
}

/**
 * @description 用户禁用或启用
 */
export function disableOrEnable(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/user/disableOrEnable',
    method: 'post',
    data,
  });
}

/**
 * @description 查询-用户已关联的组织
 */
export function getUserOrg(id: any): Promise<AxiosResponse> {
  return request({
    url: `/system/user/org/${id}`,
    method: 'get',
  });
}

/**
 * @description 用户和组织关联
 */
export function userAndOrg(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/user/userAndOrg/add',
    method: 'post',
    data,
  });
}

/**
 * @description 删除用户和组织关联
 */
export function deleteUserAndOrg(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/user/userAndOrg/delete',
    method: 'post',
    data,
  });
}

/**
 * @description 查询-用户已关联的角色
 */
export function getUserRole(id: any): Promise<AxiosResponse> {
  return request({
    url: `/system/user/role/${id}`,
    method: 'get',
  });
}

/**
 * @description 用户和角色关联
 */
export function deleteUserAndRole(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/user/userAndRole/delete',
    method: 'post',
    data,
  });
}

/**
 * @description 导出用户管理数据
 */
export function exportData(data = {}): Promise<AxiosResponse<BlobData>> {
  return request({
    url: '/system/user/export',
    method: 'get',
    params: data,
    responseType: 'blob',
  });
}

/**
 * @description 修改用户锁状态
 */
export function updateUserLockFlag<T>(data: T): Promise<AxiosResponse> {
  return request({
    url: '/system/user/updateLockFlag',
    method: 'post',
    data: qs.stringify(data),
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
  });
}

/**
 * @description 组织人员迁移
 */
export function personMagration(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/org/orgPersonMigration',
    method: 'post',
    data,
  });
}

/**
 * @description 用户密码重置
 */
export function resetUserPassword<T>(userId: T): Promise<AxiosResponse> {
  return request({
    url: `/system/user/resetUserPassword/${userId}`,
    method: 'post',
  });
}

/**
 * @description 查询-用户已关联的岗位
 */
export function getUserPost<T>(id: T): Promise<AxiosResponse> {
  return request({
    url: `/system/user/position/${id}`,
    method: 'get',
  });
}

/**
 * @description 删除用户和岗位关联
 */
export function deleteUserAndPost(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/user/userAndPost/delete',
    method: 'post',
    data,
  });
}

/**
 * @description 用户和岗位关联
 */
export function userAndPost(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/user/userAndPost/add',
    method: 'post',
    data,
  });
}

/**
 * @description 用户和角色关联
 */
export function userAndRole(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/user/userAndRole/add',
    method: 'post',
    data,
  });
}

/**
 * @description  用户下线
 */
export function offlineUser(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/user/offline',
    method: 'post',
    data: qs.stringify(data),
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
    },
  });
}
