import type { AxiosResponse } from 'axios';
import request from '@/utils/request';

/**
 * @description 树状行政区域列表
 */
export function getDistrict(): Promise<AxiosResponse> {
  return request({
    url: '/system/district/tree',
    method: 'get',
  });
}

/**
 * @description 分页查询行政地区信息
 */
export function getDistrictPage(data: any): Promise<AxiosResponse> {
  return request({
    url: '/system/district/page',
    method: 'get',
    params: data,
  });
}

/**
 * @description 添加行政地区信息
 */
export function addDistrict(data: any): Promise<AxiosResponse> {
  return request({
    url: '/system/district/save',
    method: 'post',
    data,
  });
}

/**
 * @description 修改行政地区信息
 */
export function updateDistrict(data: any): Promise<AxiosResponse> {
  return request({
    url: '/system/district/update',
    method: 'post',
    data,
  });
}

/**
 * @description 删除行政地区
 */
export function deleteDistrict(data: any): Promise<AxiosResponse> {
  return request({
    url: '/system/district/delete',
    method: 'post',
    data,
  });
}

/**
 * @description 导出指定行政地区
 */
export function getDistrictFile(): Promise<AxiosResponse> {
  return request({
    url: '/system/district/export',
    method: 'get',
    responseType: 'blob',
  });
}

/**
 * @description 行政区域数据导入
 */
export function importExcel(data: unknown): Promise<AxiosResponse> {
  return request({
    url: '/system/district/importExcel',
    method: 'post',
    data,
    headers: {
      'Content-Type': 'multipart/form-data;boundary=<calculated when request is sent>',
    },
  });
}
