import type { AxiosResponse } from 'axios';
import request from '@/utils/request';

/**
 * @description 根据数据字典类型code获取 字典项信息列表 【页面下拉 调用】
 */
export function getDictInfo(data: string): Promise<AxiosResponse> {
  return request({
    url: `/system/dict/item/info/${data}`,
    method: 'get',
  });
}

/**
 * @description 查询分页字典项信息
 */
export function getDictionaryManagement(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/dict/page',
    method: 'get',
    params: data,
  });
}

/**
 * @description 查询字典类型列表
 */
export function getDictionaryList(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/dict/type/selectList',
    method: 'get',
    params: data,
  });
}

/**
 * @description 添加数据字典信息
 */
export function addDictionaryData(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/dict/save',
    method: 'post',
    data,
  });
}

/**
 * @description 添加数据字典类别信息
 */
export function addDictionaryType(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/dict/type',
    method: 'post',
    data,
  });
}

/**
 * @description 获取数据字典详情
 */
export function getDictionaryDetail(id = ''): Promise<AxiosResponse> {
  return request({
    url: `/system/dict/info/${id}`,
    method: 'get',
  });
}

/**
 * @description 修改数据字典信息
 */
export function editDictionaryData(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/dict/update',
    method: 'post',
    data,
  });
}

/**
 * @description 删除数据字典信息
 */
export function deleteDictionaryData(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/dict/delete',
    method: 'post',
    data,
  });
}

/**
 * @description 修改数据字典类别信息
 */
export function editDictionaryType(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/dict/type/update',
    method: 'post',
    data,
  });
}

/**
 * @description 删除数据字典类别信息
 */
export function deleteDictionaryType(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/dict/type/delete',
    method: 'post',
    data,
  });
}

/**
 * @description 数据字典项的禁用和启用
 */
export function disableOrEnable(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/dict/disableOrEnable',
    method: 'post',
    data,
  });
}

/**
 * @description 导出所有数据字典
 */
export function exportAll(): Promise<AxiosResponse> {
  return request({
    url: '/system/dict/exportAll',
    method: 'get',
    responseType: 'blob',
  });
}

/**
 * @description 导出指定数据字典
 */
export function exportDict(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/dict/export',
    method: 'get',
    params: data,
    responseType: 'blob',
  });
}

/**
 * @description 判断当前字典是否有子文件夹
 */
export function isDictHasChildren(data: unknown): Promise<AxiosResponse> {
  return request({
    method: 'post',
    url: '/system/dict/type/existChildren',
    data,
  });
}

/**
 * @description 字典数据导入
 */
export function importExcel(data: unknown): Promise<AxiosResponse> {
  return request({
    url: '/system/dict/importExcel',
    method: 'post',
    data,
    headers: {
      'Content-Type': 'multipart/form-data;boundary=<calculated when request is sent>',
    },
  });
}

/**
 * @description 获取父节点下拉选项
 */
export function getParentNodesOptions(data = {}): Promise<AxiosResponse> {
  return request({
    url: '/system/dict/getParentNodes',
    method: 'get',
    params: data,
  });
}
