import type { AxiosResponse } from 'axios';
import qs from 'qs';
import request from '@/utils/request';

/**
 * @description 查询日志信息
 */
export function getLoginlog(data: any): Promise<AxiosResponse> {
  return request({
    url: '/system/loginRecord/page',
    method: 'get',
    params: data,
    paramsSerializer: (params) => qs.stringify(params, { indices: false }),
  });
}

/**
 * @description 导出数据
 */
export function getFile(data: any): Promise<AxiosResponse> {
  return request({
    url: '/system/loginRecord/export',
    method: 'get',
    params: data,
    responseType: 'blob',
    paramsSerializer: (params) => qs.stringify(params, { indices: false }),
  });
}

/**
 * @description 删除日志
 */
export function deleteLog(type: number): Promise<AxiosResponse> {
  return request({
    url: `/system/loginRecord/deleteHistoryLog/${type}`,
    method: 'post',
  });
}

/**
 * @description 日志阙值查询
 */
export function getIsThreshold(): Promise<AxiosResponse> {
  return request({
    url: '/system/loginRecord/isThreshold',
    method: 'get',
  });
}

/**
 * @description 获取备份文件列表
 */
export function getBackupFiles(): Promise<AxiosResponse> {
  return request({
    url: '/system/loginRecord/getBackupFiles',
    method: 'get',
  });
}

/**
 * @description 批量删除历史备份
 */
export function deleteBackupFiles(data): Promise<AxiosResponse> {
  return request({
    url: '/system/loginRecord/deleteBackupFiles',
    method: 'post',
    data,
  });
}

/**
 * @description 备份
 */
export function backup(): Promise<AxiosResponse> {
  return request({
    url: '/system/loginRecord/backup',
    method: 'get',
  });
}

/**
 * @description 恢复
 */
export function recover(data): Promise<AxiosResponse> {
  return request({
    url: '/system/loginRecord/recover',
    method: 'get',
    params: data,
  });
}

/**
 * @description 保存日志
 */
export function saveSystemLog(data): Promise<AxiosResponse> {
  return request({
    url: '/system/systemLog/save',
    method: 'post',
    data,
  });
}
