import qs from 'qs';
import type { AxiosResponse } from 'axios';
import request from '@/utils/request';

/**
 * @description 获取公告列表
 */
export const getAnnouncementPage = (params = {}): Promise<AxiosResponse> =>
  request({
    url: '/message/information/getAnnouncementPage',
    method: 'get',
    params,
    paramsSerializer: (params) => qs.stringify(params, { indices: false }),
  });

/**
 * @description 发布公告
 */
export const releaseAnnouncement = (data = {}): Promise<AxiosResponse> =>
  request({
    url: '/message/information/releaseAnnouncement',
    method: 'post',
    data,
  });
/**
 * @description 新增公告
 */
export const saveAnnouncement = (data = {}): Promise<AxiosResponse> =>
  request({
    url: '/message/information/saveAnnouncement',
    method: 'post',
    data,
  });

/**
 * @description 更新公告
 */
export const updateAnnouncement = (data = {}): Promise<AxiosResponse> =>
  request({
    url: '/message/information/updateAnnouncement',
    method: 'post',
    data,
  });

/**
 * @description 撤回公告
 */
export const returnAnnouncement = (data = {}): Promise<AxiosResponse> =>
  request({
    url: '/message/information/announcementWithdrawn',
    method: 'post',
    data,
  });

/**
 * @description 获取私信列表
 */
export const getPersonalLetterPage = (params): Promise<AxiosResponse> =>
  request({
    url: '/message/information/getPersonalLetterPage',
    method: 'get',
    params,
  });

/**
 * @description 获取人员树
 */
export const getPeopleTree = (): Promise<AxiosResponse> =>
  request({
    url: '/system/org/getRecipient',
    method: 'get',
  });

/**
 * @description 新增私信
 */
export const savePersonalLetter = (data = {}): Promise<AxiosResponse> =>
  request({
    url: '/message/information/savePersonalLetter',
    method: 'post',
    data,
  });

/**
 * @description 更新私信
 */
export const updatePersonalLetter = (data = {}): Promise<AxiosResponse> =>
  request({
    url: '/message/information/updatePersonalLetter',
    method: 'post',
    data,
  });

/**
 * @description 发送私信
 */
export const releasePersonalLetter = (data = {}): Promise<AxiosResponse> =>
  request({
    url: '/message/information/releasePersonalLetter',
    method: 'post',
    data,
  });

/**
 * @description 获取未读消息列表
 */
export const getAllUnreadPersonalLetter = (data = {}): Promise<AxiosResponse> =>
  request({
    url: '/message/information/getAllUnreadPersonalLetter',
    method: 'get',
    data,
  });

/**
 * @description 查看详情(私信)
 */
export const getPersonalLetterInfo = (id: string): Promise<AxiosResponse> =>
  request({
    url: `/message/information/getPersonalLetterInfo/${id}`,
    method: 'get',
  });

/**
 * @description 查看详情(公告)
 */
export const getAnnouncementInfo = (id: string): Promise<AxiosResponse> =>
  request({
    url: `/message/information/getAnnouncementInfo/${id}`,
    method: 'get',
  });

/**
 * @description 上传文件
 */
export const uploadFile = (data = {}): Promise<AxiosResponse> =>
  request({
    url: '/message/information/upload',
    method: 'post',
    data,
  });
