import type { AxiosResponse } from 'axios';
import qs from 'qs';
import request from '@/utils/request';

/**
 * @description 查询日志信息
 */
export function getOperationLog(data: any): Promise<AxiosResponse> {
  return request({
    url: '/system/log/page',
    method: 'get',
    params: data,
    paramsSerializer: (params) => qs.stringify(params, { indices: false }),
  });
}

/**
 * @description 日志阙值查询
 */
export function getIsThreshold(): Promise<AxiosResponse> {
  return request({
    url: '/system/log/isThreshold',
    method: 'get',
  });
}

/**
 * @description 删除日志
 */
export function deleteHistoryLog(id = ''): Promise<AxiosResponse> {
  return request({
    url: `/system/log/deleteHistoryLog/${id}`,
    method: 'post',
  });
}

/**
 * @description 导出数据
 */
export function getFile(data: any): Promise<AxiosResponse> {
  return request({
    url: '/system/log/export',
    method: 'get',
    params: data,
    responseType: 'blob',
    paramsSerializer: (params) => qs.stringify(params, { indices: false }),
  });
}

/**
 * @description 获取备份文件列表
 */
export function getBackupFiles(): Promise<AxiosResponse> {
  return request({
    url: '/system/log/getBackupFiles',
    method: 'get',
  });
}

/**
 * @description 批量删除历史备份
 */
export function deleteBackupFiles(data): Promise<AxiosResponse> {
  return request({
    url: '/system/log/deleteBackupFiles',
    method: 'post',
    data,
  });
}

/**
 * @description 备份
 */
export function backup(): Promise<AxiosResponse> {
  return request({
    url: '/system/log/backup',
    method: 'get',
  });
}

/**
 * @description 恢复
 */
export function recover(data): Promise<AxiosResponse> {
  return request({
    url: '/system/log/recover',
    method: 'get',
    params: data,
  });
}
