import { toRefs, onMounted, reactive } from 'vue';
import type { AxiosResponse } from 'axios';

export interface AccountRequest {
  pageNo: number;
  pageSize: number;
  [propName: string]: number | string;
}

export default function useRecordsSearch(
  getAccountApi: (params: AccountRequest) => Promise<AxiosResponse>,
  searchParmas: any = {},
): any {
  const state = reactive({
    data: [],
    total: 0,
    pageNo: 1,
    pageSize: 20,
    loading: false,
    multipleSelection: [],
    searchValue: {},
  });

  // 判断是否为空对象
  const isEmpty = (obj: any) => Reflect.ownKeys(obj).length === 0 && obj.constructor === Object;

  // 请求数据
  const initData = async () => {
    state.data = [];
    state.loading = true;
    const queryForm = {
      pageNo: state.pageNo,
      pageSize: state.pageSize,
      ...state.searchValue,
      ...(!isEmpty(searchParmas) && searchParmas.value),
    };
    try {
      const res = await getAccountApi(queryForm);
      state.data = res.data.records;
      state.total = res.data.total;
    } catch (err) {
    } finally {
      state.loading = false;
    }
  };

  // 重置数据
  const resetTableState = () => {
    state.pageNo = 1;
  };

  // 检索数据
  const handleSearch = (val: any) => {
    state.searchValue = val;
    resetTableState();
    initData();
  };

  const handleSizeChange = (v: number) => {
    (state.pageSize = v) && initData();
  };
  const handleCurrentChange = (v: number) => {
    (state.pageNo = v) && initData();
  };
  const handleSelectionChange = (v: never[]) => {
    state.multipleSelection = v;
  };
  onMounted(async () => {
    isEmpty(searchParmas) && initData();
  });

  return {
    ...toRefs(state),
    initData,
    handleSizeChange,
    handleCurrentChange,
    handleSelectionChange,
    handleSearch,
  };
}
