import { computed, reactive } from 'vue';
import { storeToRefs } from 'pinia';
import type { ITheme } from '@/types/theme';
import { useLayoutStore } from '@/store/modules/layout';

export default function getTheme(): { theme: ITheme } {
  const { setting } = storeToRefs(useLayoutStore());
  const headerBg = computed(() => setting.value.color.headerBg);
  const primaryColor = computed(() => setting.value.color.primary);

  const theme = reactive<ITheme>({
    // 颜色
    primaryColor,
    t1Color: '#262626', // 标题色
    t2Color: '#595959', // 文字内容色
    t3Color: '#8c8c8c', // 文字说明色
    t4Color: '#BFBFBF', // 文字占位色
    s1Color: '#D9D9D9', // 边框色1
    s2Color: '#E6E6E6', // 边框色2
    d1Color: '#EBEBEB', // 分割线1
    d2Color: '#F0F0F0', // 分割线2
    d3Color: '#FAFAFA', // 分割线2
    n1Color: '#666666', // 图标色1
    n2Color: '#999999', // 图标色2
    n3Color: '#CCCCCC', // 图标色2

    // 头部样式
    headerHeight: '48px',
    headerBg,
    headerColor: '#fff',

    // 路由标签
    tagsActiveColor: primaryColor,
    tagsActiveBg: '#EFF5FF',

    // 侧边栏
    sidebarWidth: '200px',
    sidebarColor: '#fff',
    sidebarActiveBg: primaryColor,
    menuInlineBg: '#FAFBFF',
    menuItemHeight: '48px',

    // 表格
    tableActiveRowBg: '#eff5ff',
    tableHeaderCellBg: '#fafafa',
    tableHeaderCellSize: '14px',
    tableHeaderCellColor: '#595959',
    tableFontSize: '14px',
    tableDangerBtnColor: '#f56c6c',

    // 面包屑
    breadcrumbFontSize: '12px',
  });
  return {
    theme,
  };
}
