import type { App, DirectiveBinding } from 'vue';
import { fetchPermissionOperate } from '@/utils/tools';

const handleDOMDisabled = (el: Element) => {
  const disabledDOM = (ele: Element) => {
    ele.setAttribute('disabled', '');
    ele.className = ele.className.split(' ').concat(['is-disabled']).join(' ').trimStart();
  };
  disabledDOM(el);
  // 针对div内部嵌套button
  if (el.tagName.toLowerCase() === 'div') {
    [...el.getElementsByTagName('button')].forEach((btnEl) => {
      disabledDOM(btnEl);
    });
  }
};

const actionPermission = (el: HTMLElement, binding: DirectiveBinding) => {
  const [hasPermission, operate] = fetchPermissionOperate(binding.value);
  // 根据 permission 判断是否显示
  if (!hasPermission) {
    el.parentNode && el.parentNode.removeChild(el);
  } else {
    if (operate === 1) {
      // 1 只读
      handleDOMDisabled(el);
    }
  }
};

export default (app: App<Element>): void => {
  app.directive('action', {
    mounted: (el, binding) => {
      actionPermission(el, binding);
    },
  });
};
