import { configure, start, done } from 'nprogress';
import type { RouteRecordRaw } from 'vue-router';
import { storeToRefs } from 'pinia';
import router from '@/router';
import { decode } from '@/utils/tools';
import { useLayoutStore } from '@/store/modules/layout';
import { useSystemStore } from '@/store/modules/system';

configure({ showSpinner: false });

const loginRoutePath = '/Login';
let defaultRoutePath = '/';
router.beforeEach(async (to, from) => {
  start();
  const {
    GenerateRoutes,
    getMenubar,
    concatAllowRoutes,
    changeTabNavList,
    addCachedViews,
    getTabs,
  } = useLayoutStore();
  const { getDefaultRoutePath, initIsLogin } = useSystemStore();
  const { isLogin } = storeToRefs(useSystemStore());
  defaultRoutePath = getDefaultRoutePath.path;

  // 修改页面title
  const reg = /^(.+)(\s\|\s.+)$/;
  const appTitle = import.meta.env.VITE_APP_TITLE as string;
  const appTitleReg = appTitle.match(reg)
    ? appTitle.replace(reg, `${to.meta.title}$2`)
    : `${to.meta.title} | ${appTitle}`;
  document.title = !to.meta.title ? appTitle : appTitleReg;

  if (isLogin.value === null) {
    initIsLogin();
  }

  // 判断当前是否在登陆页面
  if (to.path.toLocaleLowerCase() === loginRoutePath.toLocaleLowerCase()) {
    done();
    if (isLogin.value) {
      return typeof to.query.from === 'string' ? decode(to.query.from) : defaultRoutePath;
    }
    return;
  }
  // 判断是否登录
  if (!isLogin.value) {
    return loginRoutePath;
  }
  // 判断是否还没添加过路由
  if (getMenubar.menuList.length === 0) {
    await GenerateRoutes();
    // 把其他静态路由混入 pinia 的 menuList
    concatAllowRoutes();
    for (let i = 0; i < getMenubar.menuList.length; i++) {
      router.addRoute(getMenubar.menuList[i] as RouteRecordRaw);
    }
    return to.fullPath;
  }
  // 判断是否为'/',重定向到第一个路由
  if (to.path === '/') {
    return defaultRoutePath;
  }
  changeTabNavList(to); // 切换导航，记录打开的导航(标签页)

  // 离开当前页面时是否需要添加当前页面缓存
  !/^\/redirect\//.test(from.path) &&
    getTabs.tabsList.some((v) => v.name === from.name) &&
    !getTabs.cachedViews.some((v) => v === from.name) &&
    addCachedViews({
      name: from.name as string,
      noCache: from.meta.noCache as boolean,
    });
});

router.afterEach(() => {
  done();
});
