import { v4 as uuidv4 } from 'uuid';

import type { MenuList } from '@/types/store/layout';
import { useLayoutStore } from '@/store/modules/layout';
import type { IObject } from '@/types/global';
import { listToTree } from '@/utils/tools';

const getComponents = (): IObject<() => Promise<typeof import('*.vue')>> => {
  // 动态路由名称映射表
  const modules = import.meta.glob('../views/**/**.vue');
  const components: IObject<() => Promise<typeof import('*.vue')>> = {
    Layout: (() => import('@/layout/index.vue')) as unknown as () => Promise<
      typeof import('*.vue')
    >,
    LayoutBlank: (() => import('@/layout/blank.vue')) as unknown as () => Promise<
      typeof import('*.vue')
    >,
  };

  Object.keys(modules).forEach((key) => {
    const nameMatch = key.match(/^\.\.\/views(.+)\.vue/);
    if (!nameMatch) return;
    // 排除_Components文件夹下的文件
    if (nameMatch[1].includes('_Components')) return;
    // 以页面的地址为key 例子： '/SystemManagement/AdministrativeRegion/index'
    components[nameMatch[1]] = modules[key] as () => Promise<typeof import('*.vue')>;
  });
  return components;
};

const components = getComponents();
const asyncRouter: MenuList[] = [
  {
    path: '/:pathMatch(.*)*',
    name: 'NotFound',
    component: components['/ErrorPage/404'],
    meta: {
      title: 'NotFound',
      icon: '',
      hidden: true,
    },
    redirect: {
      name: '404',
    },
  },
];

// 获取目录下首个菜单路径
const getFirstMenuPath = function (routerList: MenuList[]) {
  let menuRouter = '';
  for (let i = 0; i < routerList.length; i++) {
    const router = routerList[i];
    if (router?.type === '-1') {
      menuRouter = router.path;
    } else if (router.children?.length) {
      menuRouter = getFirstMenuPath(router.children);
    }
    if (menuRouter) {
      break;
    }
  }
  return menuRouter;
};
// 生成动态路由
const generatorDynamicRouter = (data: any[]): void => {
  const { setRoutes } = useLayoutStore();
  const routerList = listToTree(data, '-1');
  asyncRouter.forEach((v) => routerList.push(v));
  const f = (data: MenuList[]) => {
    for (let i = 0, len = data.length; i < len; i++) {
      const v: MenuList = data[i];
      if (Number(v.type) === 0 || Number(v.type) === 2) {
        v.component = components['LayoutBlank'];
        // 目录重定向到第一个菜单
        if (v.children?.length) {
          v.redirect = getFirstMenuPath(v.children);
        }
      } else {
        if (!v.component) {
          v.component = components['/ErrorPage/NotFound'];
        } else {
          v.component = components[v.component as string];
        }
      }
      // path为null时赋空字符串
      if (!v.path) {
        v.path = uuidv4();
      }
      if (!v.name) {
        v.name = uuidv4();
      }
      if (v.children && v.children.length > 0) {
        f(v.children);
      }
    }
  };
  f(routerList);
  setRoutes(routerList);
};
export { components, generatorDynamicRouter, getComponents };
