import type { RouteRecordRaw } from 'vue-router';
import { createRouter, createWebHashHistory } from 'vue-router';
import type { MenuList } from '@/types/store/layout';
import { getComponents } from '@/router/asyncRouter';
import type { IObject } from '@/types/global';

const components = getComponents();

const Components: IObject<() => Promise<typeof import('*.vue')>> = {
  ...components,
  Redirect: (() => import('@/layout/redirect.vue')) as unknown as () => Promise<
    typeof import('*.vue')
  >,
};

export const allowRouter: Array<MenuList> = [
  {
    name: 'index',
    path: '/',
    component: Components['Layout'],
    redirect: '/Dashboard/Workplace',
    meta: { title: '主页', alwaysShow: true },
    children: [
      {
        name: 'Workplace',
        path: '/Dashboard/Workplace',
        component: Components['/Dashboard/Workplace/index'],
        meta: { title: '工作台', icon: 'HomeFilled', hidden: false, isShowOnMenu: true },
        type: '-1',
      },
      {
        name: 'Notification',
        path: '/permission-management/notification',
        component: Components['/SystemManagement/Notification/index'],
        meta: { title: '消息通知', hidden: true, isShowOnMenu: false },
        type: '-1',
      },
    ],
  },
  {
    name: 'ErrorPage',
    path: '/ErrorPage',
    meta: {
      title: '错误页面',
      icon: 'el-icon-eleme',
      hidden: true,
    },
    component: Components.Layout,
    redirect: '/ErrorPage/404',
    children: [
      {
        name: '401',
        path: '/ErrorPage/401',
        component: Components['/ErrorPage/401'],
        meta: { title: '401' },
      },
      {
        name: '404',
        path: '/ErrorPage/404',
        component: Components['/ErrorPage/404'],
        meta: { title: '404' },
      },
    ],
  },
  {
    name: 'RedirectPage',
    path: '/redirect',
    component: Components['Layout'],
    meta: {
      title: '重定向页面',
      icon: 'el-icon-eleme',
      hidden: true,
    },
    children: [
      {
        name: 'Redirect',
        path: '/redirect/:pathMatch(.*)*',
        meta: {
          title: '重定向页面',
          icon: '',
        },
        component: Components.Redirect,
      },
    ],
  },
  {
    name: 'Login',
    path: '/Login',
    component: Components['/Login/index'],
    meta: { title: '登录', hidden: true },
  },
];

const router = createRouter({
  history: createWebHashHistory(), // createWebHistory
  routes: allowRouter as RouteRecordRaw[],
});
export default router;
