import { defineStore } from 'pinia';
import type { System, IDefaultRoutePath, IUserInfo, ISystemImage } from '@/types/store/system';
import { useLayoutStore } from '@/store/modules/layout';

export const useSystemStore = defineStore({
  id: 'system',
  state: (): System => ({
    publicKey:
      '-----BEGIN PUBLIC KEY-----MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQDKRXq3p8VoLB4P5H3aeIbwABaXJNDDfAXX/ePpY/kXCnIQbZOaxgxVOP2bYnldDxgQ3j9OiUq2celccy4ohROcGA7JCmkDqKCcLHyRlxYScbFOhO5EDac/DsRytebt03R/H1wSfVloIbIMIjN2tN+58RxUxLUhITyPGwLngPjf+wIDAQAB-----END PUBLIC KEY-----',
    defaultRoutePath: {
      path: '/',
    },
    userInfo: {
      avatarInfo: {
        id: '',
        name: '',
        url: '',
      },
      cardNo: '',
      email: '',
      id: '',
      phone: '',
      loginId: '',
      name: '',
      sex: 0,
    },
    isLogin: null,
    systemImage: {
      id: '',
      name: '',
      url: '',
    },
    systemName: '',
    systemSubTitle: '',
    tempToken: null,
  }),
  getters: {
    getPublicKey(): string {
      return this.publicKey;
    },
    getDefaultRoutePath(): IDefaultRoutePath {
      return this.defaultRoutePath;
    },
    getUserInfo(): IUserInfo {
      return this.userInfo;
    },
    getIsLogin(): boolean | null {
      return this.isLogin;
    },
    getSystemImage(): ISystemImage {
      return this.systemImage;
    },
    getSystemName(): string {
      return this.systemName;
    },
    getSystemSubTitle(): string {
      return this.systemSubTitle;
    },
    getTempToken(): any {
      return this.tempToken;
    },
  },
  actions: {
    setDefaultRoutePath(path: string): void {
      this.defaultRoutePath.path = path;
    },
    setUserInfo(userInfo: IUserInfo): void {
      this.userInfo = userInfo;
    },
    setSystemImage(systemImage: ISystemImage): void {
      this.systemImage = systemImage;
    },
    setSystemName(systemName: string): void {
      this.systemName = systemName;
    },
    setSystemSubTitle(systemSubTitle: string): void {
      this.systemSubTitle = systemSubTitle;
    },
    // 判断是否是登录状态：有token，有isLogin
    initIsLogin(): void {
      const { cookie } = document;
      const isCookie = cookie.indexOf('isLogin=1') > -1;
      const token = localStorage.getItem('TOKEN');
      const isToken = token && token !== 'undefined';
      this.isLogin = Boolean(isCookie && isToken);
    },
    // 登录成功：保存token和cookie
    saveToken<T>(data: T): void {
      this.isLogin = true;
      document.cookie = 'isLogin=1';
      localStorage.setItem('TOKEN', JSON.stringify(data));
    },

    saveTempToken(token: any): void {
      this.tempToken = token;
    },

    // 退出登录:删除token和cookie
    logout(): void {
      localStorage.removeItem('TOKEN');
      document.cookie = 'isLogin=0';
      window.location.href = '#/Login';
      // 刷新页面
      window.location.reload();
      this.isLogin = false;
      // 重新登录时清空路由数据
      const { setRoutes } = useLayoutStore();
      setRoutes && setRoutes([]);
    },
  },
});
