// WebSocket

const WebSocketMap = new Map();

export function useWebsocket() {
  // 创建websocket连接
  function createWebsocket(id: string, url: string): WebSocket {
    if (WebSocketMap.has(id)) return getWebsocketById(id);
    const baseWsUrl = (import.meta.env.VITE_APP_BASE_URL as string)
      .replace('http://', 'ws://')
      .replace('https://', 'wss://')
      .replace('/api', '');
    url = `${baseWsUrl}${url}`;
    const ws = new WebSocket(url);
    WebSocketMap.set(id, ws);
    return ws;
  }

  // 根据id获取websocket连接
  function getWebsocketById(id: string): WebSocket {
    return WebSocketMap.get(id);
  }

  // 根据id关闭websocket连接
  function closeWebsocketById(id: string) {
    const ws = getWebsocketById(id);
    if (ws) ws.close();
  }

  return {
    createWebsocket,
    getWebsocketById,
    closeWebsocketById,
  };
}
