import { toRefs, onMounted, reactive } from 'vue';
import type { FormItemRule } from 'element-plus/es/tokens/form.d';
import { getDictInfo } from '@/utils/tools';
import type { FormOption, SearchOption, FormSelectOption } from '@/types/tools';
import { getDistrict } from '@/api/permission/organization';

export default function useOptions(): any {
  const optionsState = reactive<{
    orgTypeOptions: FormSelectOption[];
    districtIdOptions: FormSelectOption[];
  }>({
    orgTypeOptions: [],
    districtIdOptions: [],
  });
  const { orgTypeOptions, districtIdOptions } = toRefs(optionsState);
  const state = reactive<{
    searchOptions: SearchOption[];
    columns: any[];
    formOptionList: FormOption[];
    formRules: Partial<Record<string, FormItemRule | FormItemRule[]>>;
  }>({
    searchOptions: [
      {
        label: '类别',
        key: 'orgType',
        type: 'select',
        options: orgTypeOptions as any,
        span: 4,
      },
      {
        label: '',
        key: 'keyword',
        type: 'text',
        placeholder: '组织名称/别名/组织说明',
        labelWidth: '0px',
      },
    ],
    columns: [
      // { slot: 'index', label: '序号' },
      { prop: 'orgName', label: '组织名称', minWidth: 100 },
      { prop: 'alias', label: '别名', minWidth: 100 },
      { prop: 'sort', label: '排序值', minWidth: 100 },
      { prop: 'orgTypeName', label: '类别', minWidth: 100 },
      { prop: 'orgDesc', label: '组织说明', minWidth: 100 },
    ],
    formOptionList: [
      {
        label: '上级组织',
        key: 'pid',
        type: 'cascader',
        span: 12,
        labelWidth: '120px',
        options: [],
        cascaderProps: { checkStrictly: true },
        placeholder: ' ',
      },
      {
        label: '组织名称',
        key: 'orgName',
        type: 'input',
        span: 12,
        labelWidth: '120px',
      },
      {
        label: '别名',
        key: 'alias',
        type: 'input',
        span: 12,
        labelWidth: '120px',
      },
      {
        label: '类别',
        key: 'orgType',
        type: 'select',
        span: 12,
        labelWidth: '120px',
        options: orgTypeOptions as any,
      },
      {
        label: '排序值',
        key: 'sort',
        type: 'inputNumber',
        span: 12,
        labelWidth: '120px',
        value: 1,
        min: 1,
      },
      {
        label: '行政区域',
        key: 'districtId',
        type: 'cascader',
        span: 12,
        labelWidth: '120px',
        options: districtIdOptions as any,
        cascaderProps: { value: 'id', label: 'name' },
      },
      {
        label: '组织说明',
        key: 'orgDesc',
        type: 'input',
        span: 24,
        labelWidth: '120px',
        inputType: 'textarea',
        rows: '2',
      },
      {
        label: '组织负责人',
        key: 'director',
        type: 'select',
        span: 12,
        labelWidth: '120px',
        options: [],
      },
    ],
    formRules: {
      pid: [
        {
          required: true,
          message: '请输入上级组织',
          trigger: 'blur',
        },
      ],
      orgName: [
        {
          required: true,
          message: '请输入组织名称',
          trigger: 'blur',
        },
      ],
      orgType: [
        {
          required: true,
          message: '请输入类别',
          trigger: 'change',
        },
      ],
      sort: [
        {
          required: true,
          message: '请输入排序值',
          trigger: 'blur',
        },
      ],
    },
  });
  const getOrgTypeOptions = async () => {
    const codeList = [{ code: 'orgType', prop: 'orgType' }];
    const options = await getDictInfo(codeList);
    optionsState.orgTypeOptions = options.orgType;
  };

  const getDistrictIdOptions = async () => {
    getDistrict().then((res) => {
      const { data } = res;
      optionsState.districtIdOptions = data;
    });
  };

  // 请求下拉列表选项
  const initOptions = async () => {
    getOrgTypeOptions();
    getDistrictIdOptions();
  };

  onMounted(async () => {
    initOptions();
  });

  return {
    ...toRefs(state),
  };
}
