import type { Ref } from 'vue';
import { toRefs, reactive, nextTick, computed } from 'vue';
import type { FormOption, FormSelectOption } from '@/types/tools';
import {
  addOrganize,
  updateOrganize,
  getOrgDirector,
  getUserListByOrgId,
} from '@/api/permission/organization';

export default function useEditOrganization(formOptionList: Ref<FormOption[]>): any {
  const state = reactive<{
    dialogVisible: boolean;
    formValue: any;
    formDisabled: boolean;
    dialogType: string;
    formOptionShowList: FormOption[];
    formRef: any;
    saveLoading: boolean;
    editData: any;
    orgUserOptions: FormSelectOption[];
  }>({
    dialogVisible: false,
    formValue: null,
    formDisabled: false,
    dialogType: '',
    formOptionShowList: [],
    formRef: null,
    saveLoading: false,
    editData: null,
    orgUserOptions: [],
  });

  // 取消编辑
  const handleCancel = () => {
    state.formValue = null;
    state.dialogVisible = false;
    nextTick(() => {
      state.formRef.restoreForm();
    });
  };

  // 新增、编辑组织
  const handleOpenDialog = async (type: string, data: any = null) => {
    state.dialogVisible = true;
    state.dialogType = type;
    switch (type) {
      case 'add':
        state.formDisabled = false;
        state.formOptionShowList = formOptionList.value.filter(
          (item: FormOption) => item.key !== 'pid',
        );
        break;
      case 'edit':
        // 获取现有组织负责人（前端为单选，后端返回list是因为以后扩展）
        data.director = await getOrgDirector({ orgId: data.id });
        data.director = data.director.data[0]?.userId;
        // 获取可选组织负责人
        getUserListByOrgId({ orgId: data.id }).then((res) => {
          const temp = res.data.map((item) => {
            item.label = item.userName;
            item.value = item.userId;
            return item;
          });
          state.formOptionShowList.forEach((item: FormOption) => {
            if (item.key === 'director') {
              item.options = temp;
            }
          });
        });
        state.editData = data;
        data.districtId =
          data.districtId && !Array.isArray(data.districtId)
            ? JSON.parse(data.districtId)
            : data.districtId;
        data.districtId = data.districtId && data.districtId?.map((item: any) => item.id ?? item);
        state.formValue = data;
        state.formDisabled = true;
        state.formOptionShowList = [...formOptionList.value];
        break;
      case 'addChild':
        state.formValue = { pid: data.id };
        state.formDisabled = false;
        state.formOptionShowList = [...formOptionList.value];
        break;
      default:
        break;
    }
  };

  const dialogTitle = computed(() => {
    if (state.dialogType === 'add') {
      return '组织架构新增';
    } else if (state.dialogType === 'edit') {
      return '组织架构信息';
    } else {
      return '新增子组织';
    }
  });

  // 保存组织架构
  const handleSave = (initData: () => void) => {
    if (state.dialogType === 'edit' && state.formDisabled) {
      state.formDisabled = false;
      return;
    }
    state.formRef.getValue().then((res: any) => {
      if (res) {
        state.saveLoading = true;
        res.director = [{ userId: res.director }];
        if (state.dialogType === 'add') res.pid = '-1';
        if (state.dialogType === 'edit') {
          res.id = state.editData.id;
          res.pid = res.pid ? res.pid : state.editData.pid;
        }
        if (Array.isArray(res.pid)) {
          res.pid = res.pid[res.pid.length - 1];
        }
        // const districtName = res.districtId.join('/')
        const _api =
          (['add', 'addChild'].includes(state.dialogType) && addOrganize) || updateOrganize;
        _api({
          ...res,
          districtId: JSON.stringify(res.districtId),
        })
          .then(() => {
            state.dialogVisible = false;
            initData();
          })
          .finally(() => {
            state.saveLoading = false;
          });
      }
    });
  };

  return {
    ...toRefs(state),
    handleCancel,
    handleOpenDialog,
    handleSave,
    dialogTitle,
  };
}
