import { toRefs, reactive } from 'vue';
import type { FormItemRule } from 'element-plus/es/tokens/form.d';
import type { FormOption, SearchOption } from '@/types/tools';

export default function useOptions(): any {
  const state = reactive<{
    searchOptions: SearchOption[];
    columns: any[];
    formOptionList: FormOption[];
    formRules: Partial<Record<string, FormItemRule | FormItemRule[]>>;
  }>({
    searchOptions: [
      {
        label: '岗位状态',
        key: 'state',
        type: 'select',
        options: [
          {
            value: '',
            label: '所有',
          },
          {
            value: '1',
            label: '启用',
          },
          {
            value: '0',
            label: '禁用',
          },
        ],
      },
      {
        label: '',
        key: 'keyword',
        type: 'text',
        placeholder: '岗位名称/岗位编码/岗位描述',
        labelWidth: '0px',
        span: 8,
      },
    ],
    columns: [
      {
        prop: 'positionName',
        label: '岗位名称',
        minWidth: 100,
        align: 'center',
      },
      {
        prop: 'positionCode',
        label: '岗位编码',
        minWidth: 100,
        align: 'center',
      },
      {
        prop: 'sort',
        label: '排序值',
        minWidth: 100,
        align: 'center',
      },
      {
        prop: 'positionDesc',
        label: '岗位描述',
        minWidth: 100,
        align: 'center',
      },
      {
        prop: 'state',
        label: '启用/禁用',
        minWidth: 100,
        align: 'center',
        slot: 'state',
      },
    ],
    formOptionList: [
      {
        label: '岗位名称',
        key: 'positionName',
        type: 'input',
        span: 12,
        labelWidth: '120px',
      },
      {
        label: '岗位编码',
        key: 'positionCode',
        type: 'input',
        span: 12,
        labelWidth: '120px',
      },
      {
        label: '排序值',
        key: 'sort',
        type: 'inputNumber',
        span: 12,
        labelWidth: '120px',
        value: 1,
        min: 1,
      },
      {
        label: '岗位描述',
        key: 'positionDesc',
        type: 'input',
        span: 24,
        labelWidth: '120px',
        inputType: 'textarea',
        rows: '2',
      },
    ],
    formRules: {
      positionName: [
        {
          required: true,
          message: '请输入岗位名称',
          trigger: 'blur',
        },
      ],
      positionCode: [
        {
          required: true,
          message: '请输入岗位编码',
          trigger: 'blur',
        },
      ],
      sort: [
        {
          required: true,
          message: '请输入排序值',
          trigger: 'blur',
        },
      ],
    },
  });

  return {
    ...toRefs(state),
  };
}
