import type { Ref } from 'vue';
import { toRefs, reactive, nextTick, computed } from 'vue';
import type { FormOption } from '@/types/tools';
import { addPost, editPost, getUserInfoByPositionId } from '@/api/permission/postManagement';

export default function useEditPost(formOptionList: Ref<FormOption[]>): any {
  const state = reactive<{
    dialogVisible: boolean;
    jobDialogVisible: boolean; // 控制“关联用户”弹窗
    currentJob: any; // 当前点击的岗位
    relateUserTreeData: any;
    formValue: any;
    formDisabled: boolean;
    dialogType: string;
    formOptionShowList: FormOption[];
    formRef: any;
    saveLoading: boolean;
    editData: any;
  }>({
    dialogVisible: false,
    jobDialogVisible: false,
    currentJob: {},
    relateUserTreeData: [],
    formValue: null,
    formDisabled: false,
    dialogType: '',
    formOptionShowList: [],
    formRef: null,
    saveLoading: false,
    editData: null,
  });

  // 取消编辑岗位
  const handleCancel = () => {
    state.formValue = null;
    state.formOptionShowList = [];
    state.dialogVisible = false;
    nextTick(() => {
      if (state.formRef) {
        state.formRef.restoreForm();
      }
    });
  };

  const handleSetRelateUserTreeData = async (positionId) => {
    try {
      const res = await getUserInfoByPositionId({ positionId });
      state.relateUserTreeData = res.data;
    } catch (err) {}
  };

  const handleOpenJobDialog = async (data: any = null) => {
    if (data) {
      try {
        state.currentJob = data;
        await handleSetRelateUserTreeData(data.id);
        state.jobDialogVisible = true;
      } catch (err) {}
    }
  };

  const handleCloseJobDialog = () => {
    state.jobDialogVisible = false;
  };

  // 打开弹框
  const handleOpenDialog = (type: string, data: any = null) => {
    state.dialogVisible = true;
    state.dialogType = type;
    switch (type) {
      case 'add':
        nextTick(() => {
          if (state.formRef) {
            state.formRef.restoreForm();
          }
        });
        state.formDisabled = false;
        state.formOptionShowList = [...formOptionList.value];
        break;
      case 'edit':
        state.editData = data;
        state.formValue = data;
        state.formDisabled = true;
        state.formOptionShowList = formOptionList.value.map((item: FormOption) => {
          const _item = {
            ...item,
          };
          if (_item.key === 'positionCode') {
            _item.disabled = true;
          }
          return _item;
        });
        break;
      default:
        break;
    }
  };

  // 弹框标题
  const dialogTitle = computed(() => {
    const dialogTitleObj = {
      add: '岗位新增',
      edit: '岗位信息',
      'user-relate': '关联用户',
    };
    return dialogTitleObj[state.dialogType] ? dialogTitleObj[state.dialogType] : '';
  });

  // 保存岗位
  const handleSave = (initData: () => void) => {
    if (state.dialogType === 'edit' && state.formDisabled) {
      state.formDisabled = false;
      return;
    }
    state.formRef.getValue().then((res: any) => {
      if (res) {
        state.saveLoading = true;
        if (state.dialogType === 'edit') {
          res.id = state.editData.id;
        }
        const _api = state.dialogType === 'add' ? addPost : editPost;
        _api(res)
          .then(() => {
            state.dialogVisible = false;
            initData();
          })
          .finally(() => {
            state.saveLoading = false;
          });
      }
    });
  };

  return {
    ...toRefs(state),
    handleCancel,
    handleOpenDialog,
    handleOpenJobDialog,
    handleCloseJobDialog,
    handleSave,
    dialogTitle,
    handleSetRelateUserTreeData,
  };
}
