import { toRefs, reactive } from 'vue';
import type { FormItemRule } from 'element-plus/es/tokens/form.d';
import { updateMenu, updateSystemMenu } from '@/api/permission/resourceManagement';

export default function useEditOrganization(): any {
  const state = reactive<{
    formDisabled: boolean;
    updateLoading: boolean;
    formRules: Partial<Record<string, FormItemRule | FormItemRule[]>>;
    messageFormRef: any;
    addDialogVisible: boolean;
  }>({
    formDisabled: true,
    updateLoading: false,
    messageFormRef: null,
    addDialogVisible: false,
    formRules: {
      name: [
        {
          required: true,
          message: '请输入名称',
          trigger: 'blur',
        },
      ],
      path: [
        {
          required: true,
          message: '请输入前端url',
          trigger: 'blur',
        },
      ],
    },
  });

  // 取消编辑
  const cancelEdit = () => {
    state.formDisabled = true;
    state.messageFormRef.restoreForm();
  };

  // 保存数据
  const handleUpdate = (currentNode: any, handleGetMenu: any) => {
    state.messageFormRef.getValue().then((res: any) => {
      if (res) {
        const updateData = { ...currentNode, ...res };
        const api = updateData.classify === 1 ? updateSystemMenu : updateMenu;
        state.updateLoading = true;
        api({ ...currentNode, ...res })
          .then(() => {
            state.formDisabled = true;
            handleGetMenu();
          })
          .finally(() => {
            state.updateLoading = false;
          });
      }
    });
  };
  return {
    ...toRefs(state),
    cancelEdit,
    handleUpdate,
  };
}
