import { toRefs, reactive, onMounted, watch } from 'vue';
import type {
  TreeOptionProps,
  FilterNodeMethodFunction,
} from 'element-plus/lib/components/tree/src/tree.type';
import type { MenuTreeData, MenuTreeDataItem } from '@/types/api/resourceManagement';
import { getMenu } from '@/api/permission/resourceManagement';

export default function useOperateOrganizationTree(): any {
  const state = reactive<{
    defaultProps: TreeOptionProps;
    searchValue: string;
    treeData: MenuTreeData;
    currentNode: MenuTreeDataItem | null;
    selectedKeys: string;
    treeLoading: boolean;
    treeRef: any;
  }>({
    defaultProps: {
      children: 'children',
      label: 'name',
      disabled: 'disabled',
    },
    searchValue: '',
    treeData: [],
    currentNode: null,
    selectedKeys: '',
    treeLoading: false,
    treeRef: null,
  });

  // 获取资源树数据
  const handleGetMenu = () => {
    state.treeLoading = true;
    getMenu()
      .then((res) => {
        const treeData = res.data;
        state.treeData = treeData;
        if (!state.currentNode) {
          const [currentNode] = treeData;
          state.currentNode = currentNode;
          state.selectedKeys = currentNode.id;
        }
      })
      .finally(() => {
        state.treeLoading = false;
      });
  };

  // 过滤树数据
  watch(
    () => state.searchValue,
    (curAge) => {
      state.treeRef?.filter(curAge);
    },
  );
  const filterNode: FilterNodeMethodFunction = (value, data) => {
    if (!value) return true;
    return data.name.indexOf(value) !== -1;
  };

  // 回调-树选择节点
  const handleClickNode = (data: MenuTreeDataItem) => {
    if (data.id) {
      if (data.id === state.selectedKeys) return;
      state.currentNode = data;
      state.selectedKeys = data.id;
    }
  };

  onMounted(() => {
    handleGetMenu();
  });

  return {
    ...toRefs(state),
    filterNode,
    handleClickNode,
    handleGetMenu,
  };
}
