import { toRefs, computed, reactive, nextTick } from 'vue';
import {
  addRole,
  editRole,
  getRoleDetail,
  getTreeRoleGroup,
  getDictionaryTree,
} from '@/api/permission/roleManagement';
import { getOrgAll, getDistrict } from '@/api/permission/organization';
import { getDictionaryList } from '@/api/systemManagement/dictionaryManagement';
import useRelationUser from '@/views/Permission/RoleManagement/composables/RelationUser';
import useRoleManage from '@/views/Permission/RoleManagement/composables/roleManage';
import type { FormSelectOption } from '@/types/tools';

const state = reactive<{
  dialogVisible: boolean;
  formValue: any;
  formDisabled: boolean;
  dialogType: '' | 'add' | 'edit' | 'child' | 'add-edit';
  formRef: any;
  saveLoading: boolean;
  editData: any;
  userInfo: any;
  roleTypeOptions: FormSelectOption[];
  roleTypeDisabled: boolean;
  relatedIdsArr: any[];
}>({
  dialogVisible: false,
  formValue: null,
  formDisabled: false,
  dialogType: '',
  formRef: null,
  saveLoading: false,
  editData: null,
  userInfo: { id: '' },
  roleTypeOptions: [],
  roleTypeDisabled: false,
  relatedIdsArr: [],
});
const { getRoleUserData } = useRelationUser();
const { changeType, setTabPanelDisabled, setAddRoleTempInfo, addRoleTempInfo } = useRoleManage();
export default function useAddRole(): any {
  // 手动设置formValue的值
  const handleSetFormValue = (formValue: any) => {
    state.formValue = formValue;
  };

  // 取消编辑
  const handleCancel = () => {
    state.formValue = null;
    state.dialogVisible = false;
    nextTick(() => {
      state.formRef.restoreForm();
    });
  };

  const getRoleTypeOptions = () => {
    getTreeRoleGroup().then((res) => {
      state.roleTypeOptions = res.data;
    });
  };

  // 树结构转数组
  const treeToArray = (data: any, prop: string) => {
    const result = <any>[];
    const loop = (item) => {
      item.forEach((res) => {
        result.push(res[prop]);
        if (res.children) loop(res.children);
      });
      return result;
    };
    return loop(data);
  };

  // 对比数组间差异
  const compareArr = (targetArr, treeArr) => {
    const res = treeArr.filter((filterItem) =>
      targetArr.some((someItem) => Object.is(filterItem, someItem)),
    );
    return res;
  };

  // 判断数据字典-当前类别在类别下拉值是否存在
  const isDictType = async (data): Promise<boolean> => {
    const target = await getDictionaryList().then((res): boolean => {
      const arr = res.data.businessList.concat(res.data.systemList).map((item) => item.typeValue);
      return !arr.includes(data.toString());
    });
    return target;
  };

  // 判断数据字典-当前类别-具体字典在数据字典下拉值是否存在
  const isDictValue = (data, list) => {
    const value = getDictionaryTree(data).then(async (res) => {
      if (res[data]?.length !== 0) {
        return compareArr(list, await treeToArray(res.data[data], 'id'));
      } else return [];
    });
    return value;
  };

  // 判断指定组织的值是否存在下拉值中
  const isOrgValue = async (data) => {
    const target = await getOrgAll().then(async (res) => {
      if (res.data?.length !== 0) {
        return compareArr(data, await treeToArray(res.data, 'id'));
      } else return [];
    });
    return target;
  };

  // 判断行政区域
  const isDistrictValue = async (data) => {
    const target = await getDistrict().then(async (res) => {
      if (res.data?.length !== 0) {
        return compareArr(data, await treeToArray(res.data, 'id'));
      } else return [];
    });
    return target;
  };

  // 打开弹框
  const handleOpenDialog = (type: '' | 'add' | 'edit' | 'child' | 'add-edit', data: any) => {
    state.relatedIdsArr = [];
    state.dialogType = type;
    getRoleTypeOptions();
    switch (type) {
      case 'add':
        state.formDisabled = false;
        state.roleTypeDisabled = false;
        state.formValue = { type: 0, relatedIds: '', roleType: 0 };
        break;
      case 'edit':
        getRoleDetail(data.id).then(async (res) => {
          res.data.type = res.data.dataScopeType;
          res.data.relatedIds = res.data.roleAndScopeVO?.relatedIds;
          res.data.relatedId = res.data.roleAndScopeVO?.dictTypeId;
          state.formDisabled = true;
          state.roleTypeDisabled = true;
          if (res.data.type === 1) {
            res.data.relatedIds = await isOrgValue(res.data.relatedIds);
          }
          if (res.data.type === 7) {
            res.data.relatedIds = await isDistrictValue(res.data.relatedIds);
          }
          if (res.data.type === 8) {
            if (await isDictType(res.data.relatedId)) {
              res.data.relatedId = '';
            }
            if (res.data.relatedId) {
              res.data.relatedIds = await isDictValue(res.data.relatedId, res.data.relatedIds);
            }
          }
          state.editData = res.data;
          state.formValue = res.data;
        });
        break;
      case 'child':
        state.formDisabled = false;
        state.roleTypeDisabled = false;
        state.formValue = { type: 0, relatedIds: '', parentId: data.id, roleType: 0 };
        break;
      default:
        break;
    }
    state.dialogVisible = true;
  };

  // 弹框标题
  const dialogTitle = computed(() => {
    if (state.dialogType === 'add') {
      return '角色新增';
    } else {
      return '角色信息';
    }
  });

  // 保存数据
  const handleSave = (initData: () => void) => {
    if (state.dialogType === 'edit' && state.formDisabled) {
      state.formDisabled = false;
      return;
    }
    state.formRef.getValue().then((res: any) => {
      if (res) {
        res.dataScopeType = res.type;
        res.roleAndScopeVO = {
          dictTypeId: res.relatedId,
          relatedIds: res.relatedIds,
        };
        state.saveLoading = true;
        if (['edit'].includes(state.dialogType)) {
          res.id = state.editData.id;
        } else if (['add-edit'].includes(state.dialogType)) {
          res.id = addRoleTempInfo.value;
        }
        const _api = ['add', 'child'].includes(state.dialogType) ? addRole : editRole;
        _api(res)
          .then((result) => {
            if (['add', 'child'].includes(state.dialogType)) {
              state.userInfo = { id: result.data };
              if (res.roleType === 0) {
                // 当新增的角色类型为 “角色”
                state.dialogType = 'add-edit';
                state.roleTypeDisabled = true; // 禁用 ”角色类型“
                changeType('resources'); // 跳转到【关联资源】tab
                setTabPanelDisabled(false); // 设置可以跳回 “基本信息” 进行编辑
                setAddRoleTempInfo(result.data); // 存储当前新增的角色的id
                getRoleUserData(state.userInfo);
              } else state.dialogVisible = false;
            } else if (['edit'].includes(state.dialogType)) {
              state.dialogVisible = false;
            }
            initData();
          })
          .finally(() => {
            state.saveLoading = false;
          });
      }
    });
  };

  return {
    ...toRefs(state),
    handleCancel,
    handleOpenDialog,
    dialogTitle,
    handleSave,
    handleSetFormValue,
  };
}
