import { toRefs, reactive, computed } from 'vue';
import type { AxiosResponse } from 'axios';
import {
  getRoleUser,
  updateUserToRole,
  addUserToRole,
  deleteUserToRole,
} from '@/api/permission/roleManagement';

const state = reactive<{
  transferDialogVisible: boolean;
  userTransferValue: any;
  userData: any;
  transferDialogType: string;
  relationEditData: any;
  userTransferLoading: boolean;
}>({
  transferDialogVisible: false,
  userTransferValue: [],
  userData: [],
  transferDialogType: '',
  relationEditData: null,
  userTransferLoading: false,
});
export default function useRelationUser(): any {
  const userTransferProps = {
    key: 'id',
    label: 'name',
    disabled: 'disabled',
  };

  const userTransferTitles: [string, string] = ['可选用户', '已关联用户'];
  const userTransferValueId = computed(() => state.userTransferValue.map((el: any) => el.id));

  const userTransferRender = (h: any, option: any) => h('span', null, option.name);

  /**
   * 获取角色关联用户
   */
  const getRoleUserData = (row: any) => {
    state.userTransferLoading = true;
    getRoleUser(row.id)
      .then((res) => {
        if (res.data?.optionalList && res.data?.selectedList) {
          const { optionalList, selectedList } = res.data;
          const allData = optionalList.concat(selectedList);
          state.userData = allData;
          state.userTransferValue = selectedList;
        }
      })
      .catch()
      .finally(() => {
        state.userTransferLoading = false;
      });
  };

  // 打开关联用户弹框
  const handleOpenUserDialog = (e: Event, row: any, type: string) => {
    e.stopPropagation();
    state.relationEditData = row;
    state.transferDialogVisible = true;
    state.transferDialogType = type;
    if (type === 'user') {
      getRoleUserData(row);
    }
  };

  /**
   * 关联用户
   * @param targetKeys 当前值
   * @param direction 方向
   * @param moveKeys 发生移动的数据 key 数组
   */
  const handleChangeUserTransfer = (targetKeys: any, direction: any, moveKeys: any, info: any) => {
    let requestApi: (param) => Promise<AxiosResponse>;
    let arr: any = [];
    if (direction === 'right') {
      arr = state.userData.filter((item: any) => moveKeys.includes(item.id));
      state.userTransferValue = state.userTransferValue.concat(arr);
      requestApi = addUserToRole;
    }
    if (direction === 'left') {
      arr = state.userData.filter((item: any) => moveKeys.includes(item.id));
      const ids = arr.map((el: any) => el.id);
      state.userTransferValue = state.userTransferValue.filter((el: any) => !ids.includes(el.id));
      requestApi = deleteUserToRole;
    }
    const userIds = arr.map((item: any) => ({
      userId: item.id,
      userName: item.name,
    }));
    let param = {};
    if (state.relationEditData) {
      param = {
        roleId: state.relationEditData.id,
        roleName: state.relationEditData.roleName,
        userIds,
      };
    } else {
      param = {
        roleId: info.id,
        roleName: info.roleName,
        userIds,
      };
    }

    requestApi!(param).then(() => {
      if (direction === 'left') {
        const ids = arr.map((el: any) => el.id);
        state.userTransferValue = state.userTransferValue.filter((el: any) => !ids.includes(el.id));
      } else if (direction === 'right') {
        state.userTransferValue = state.userTransferValue.concat(arr);
      }
      // cb();
    });
  };

  const updateRoleUser = (row?: any, handle?: any) => {
    const userIds = state.userTransferValue.map((item: any) => ({
      userId: item.id,
    }));
    const param = {
      roleId: row ? row.id : state.relationEditData.id,
      userIds,
    };
    updateUserToRole(param).then(() => {
      if (handle) {
        handle();
      }
    });
  };

  return {
    ...toRefs(state),
    userTransferProps,
    userTransferTitles,
    userTransferValueId,
    userTransferRender,
    handleOpenUserDialog,
    handleChangeUserTransfer,
    updateRoleUser,
    getRoleUserData,
  };
}
