import { toRefs, reactive, computed, nextTick } from 'vue';
import useOptions from './data';
import { decrypt, encryption } from '@/utils/encryption';
import { useSystemStore } from '@/store/modules/system';
import type { FormOption } from '@/types/tools';
import { getUserInfo, editUser, addUser } from '@/api/permission/userManagement';
import useRelationRole from './relationRole';

const { userFormOptionList } = useOptions();
const { getPublicKey } = useSystemStore();
const state = reactive<{
  userDialogVisible: boolean;
  userDialogType: string;
  userFormValue: any;
  userformRef: any;
  userFormDisabled: boolean;
  userFormShowOptionList: FormOption[];
  editData: any;
  saveLoading: boolean;
  addUserActive: string;
  addUserName: string;
  addData: any;
  tabPanelDisabled: boolean;
}>({
  userDialogVisible: false,
  userDialogType: '',
  userFormValue: null,
  userformRef: null,
  userFormDisabled: false,
  userFormShowOptionList: [],
  editData: null,
  saveLoading: false,
  addUserActive: 'info',
  addUserName: '',
  addData: {},
  tabPanelDisabled: true,
});
export default function useAddUser(props: any, handleChangeOrgTab?: any): any {
  // 关联角色功能
  const { getUserRoleData } = useRelationRole();

  // 弹框标题
  const dialogTitle = computed(() => {
    if (state.userDialogType === 'add') {
      return '用户新增';
    } else {
      return '用户信息';
    }
  });

  // 打开弹框
  const handleOpenDialog = (type: string, data: any = null) => {
    if (!props.currentOrganizeData) return;
    state.userDialogType = type;
    state.userDialogVisible = true;
    switch (type) {
      case 'add':
        state.userFormDisabled = false;
        state.userFormShowOptionList = [...userFormOptionList.value];
        state.userFormValue = {
          orgNames: props.currentOrganizeData.orgName,
          orgId: [props.currentOrganizeData.id],
          sex: 1,
        };
        break;
      case 'edit':
        state.editData = data;
        state.userFormShowOptionList = userFormOptionList.value.map((item: FormOption) => {
          const _item = {
            ...item,
          };
          if (_item.key === 'loginId') {
            _item.disabled = true;
          }
          return _item;
        });
        state.userFormDisabled = true;
        getUserInfo(data.id).then((res) => {
          res.data.cardNo && (res.data.cardNo = decrypt(res.data.cardNo, getPublicKey));
          res.data.phone && (res.data.phone = decrypt(res.data.phone, getPublicKey));
          const formData = Object.assign(res.data, {
            organize: props.currentOrganizeData.orgName,
          });
          if (res.data) {
            state.userFormValue = formData;
          }
        });
        break;
      default:
        break;
    }
  };

  // 取消编辑用户
  const handleCancel = () => {
    state.userFormValue = null;
    state.userDialogVisible = false;
    state.addUserActive = 'info';
    nextTick(() => {
      state.userformRef.restoreForm();
    });
  };

  // 保存数据
  const handleSave = (initData: any) => {
    if (state.userDialogType === 'edit' && state.userFormDisabled) {
      state.userFormDisabled = false;
      return;
    }
    state.userformRef.getValue().then((res: any) => {
      if (res) {
        state.saveLoading = true;
        res.cardNo && (res.cardNo = encryption(res.cardNo, getPublicKey));
        res.phone && (res.phone = encryption(res.phone, getPublicKey));
        res.organize && delete res.organize;
        res.id = state.userFormValue.id;
        res.orgId = state.userFormValue.orgId;
        res.positionId = state.userFormValue.positionId;
        const _api = state.userDialogType === 'add' ? addUser : editUser;
        state.addData = res;
        _api(res)
          .then((result) => {
            if (state.userDialogType === 'add') {
              state.tabPanelDisabled = false;
              state.addUserName = res.name;
              state.addData.id = result.data;
              getUserRoleData({ id: result.data, name: res.name });
              res.id = result.data;
              state.userFormValue.id = res.id;
              state.addUserActive = 'org';
              handleChangeOrgTab(res);
            } else {
              state.userDialogVisible = false;
            }
            initData();
          })
          .finally(() => {
            state.saveLoading = false;
          });
      }
    });
  };

  return {
    ...toRefs(state),
    dialogTitle,
    handleOpenDialog,
    handleCancel,
    handleSave,
  };
}
