import { toRefs, reactive } from 'vue';
import type { FormItemRule } from 'element-plus/es/tokens/form.d';
import { getDictInfo } from '@/utils/tools';
import type { FormOption, SearchOption, FormSelectOption } from '@/types/tools';
import { getDistrict } from '@/api/permission/organization';

export default function useOptions(): any {
  const optionsState = reactive<{
    orgTypeOptions: FormSelectOption[];
    districtIdOptions: FormSelectOption[];
    organizeTreeOptions: any;
  }>({
    orgTypeOptions: [],
    districtIdOptions: [],
    organizeTreeOptions: [],
  });
  const { orgTypeOptions, districtIdOptions, organizeTreeOptions } = toRefs(optionsState);
  const state = reactive<{
    searchOptions: SearchOption[];
    columns: any[];
    organizeFormOptionList: FormOption[];
    userFormOptionList: FormOption[];
    organizeFormRules: Partial<Record<string, FormItemRule | FormItemRule[]>>;
    userFormRules: Partial<Record<string, FormItemRule | FormItemRule[]>>;
    migrationFormRules: Partial<Record<string, FormItemRule | FormItemRule[]>>;
    migrationFormOptionList: FormOption[];
  }>({
    searchOptions: [
      {
        label: '在线状态',
        key: 'isOnline',
        type: 'select',
        options: [
          {
            value: '',
            label: '所有',
          },
          {
            value: 'true',
            label: '在线',
          },
          {
            value: 'false',
            label: '离线',
          },
        ],
      },
      {
        label: '账号状态',
        key: 'lockFlag',
        type: 'select',
        options: [
          {
            value: '',
            label: '所有',
          },
          {
            value: '0',
            label: '可用',
          },
          {
            value: '1',
            label: '禁用',
          },
          {
            value: '9',
            label: '锁定',
          },
        ],
      },
      {
        label: '',
        key: 'keyword',
        type: 'text',
        placeholder: '用户姓名/登录账号/手机号/邮箱/身份证/组织',
        labelWidth: '0px',
        span: 8,
      },
    ],
    columns: [
      // { slot: 'index', label: '序号' },
      {
        prop: 'name',
        label: '用户姓名',
        align: 'center',
        minWidth: 100,
      },
      {
        prop: 'loginId',
        label: '登录账号',
        align: 'center',
        minWidth: 100,
      },
      {
        prop: 'phone1',
        label: '手机号',
        align: 'center',
        minWidth: 100,
      },
      {
        prop: 'email',
        label: '邮箱',
        align: 'center',
        minWidth: 140,
      },
      {
        prop: 'cardNo1',
        label: '身份证',
        align: 'center',
        minWidth: 140,
      },
      {
        prop: 'orgNames',
        label: '组织',
        align: 'center',
        minWidth: 100,
      },
      {
        prop: 'lockFlag',
        label: '状态',
        minWidth: 80,
        align: 'center',
        slot: 'lockFlag',
      },
    ],
    organizeFormOptionList: [
      {
        label: '上级组织',
        key: 'pid',
        type: 'cascader',
        span: 12,
        labelWidth: '120px',
        options: organizeTreeOptions as any,
        cascaderProps: {
          checkStrictly: true,
          label: 'orgName',
          value: 'id',
        },
        placeholder: ' ',
      },
      {
        label: '组织名称',
        key: 'orgName',
        type: 'input',
        span: 12,
        labelWidth: '120px',
      },
      {
        label: '别名',
        key: 'alias',
        type: 'input',
        span: 12,
        labelWidth: '120px',
      },
      {
        label: '类别',
        key: 'orgType',
        type: 'select',
        span: 12,
        labelWidth: '120px',
        options: orgTypeOptions as any,
      },
      {
        label: '排序值',
        key: 'sort',
        type: 'inputNumber',
        span: 12,
        labelWidth: '120px',
        value: 1,
        min: 1,
      },
      {
        label: '行政区域',
        key: 'districtId',
        type: 'cascader',
        span: 12,
        labelWidth: '120px',
        options: districtIdOptions as any,
        cascaderProps: { value: 'id', label: 'name' },
      },
      {
        label: '组织说明',
        key: 'orgDesc',
        type: 'input',
        span: 24,
        labelWidth: '120px',
        inputType: 'textarea',
        rows: '2',
      },
      {
        label: '组织负责人',
        key: 'director',
        type: 'select',
        span: 12,
        labelWidth: '120px',
        options: [],
      },
    ],
    organizeFormRules: {
      pid: [
        {
          required: true,
          message: '请输入上级组织',
          trigger: 'blur',
        },
      ],
      orgName: [
        {
          required: true,
          message: '请输入组织名称',
          trigger: 'blur',
        },
      ],
      orgType: [
        {
          required: true,
          message: '请输入类别',
          trigger: 'change',
        },
      ],
      sort: [
        {
          required: true,
          message: '请输入排序值',
          trigger: 'blur',
        },
      ],
    },
    userFormOptionList: [
      {
        label: '用户姓名',
        key: 'name',
        type: 'input',
        span: 12,
        labelWidth: '120px',
      },
      {
        label: '登录账号',
        key: 'loginId',
        type: 'input',
        span: 12,
        labelWidth: '120px',
      },
      {
        label: '手机号',
        key: 'phone',
        type: 'input',
        span: 12,
        labelWidth: '120px',
      },
      {
        label: '邮箱',
        key: 'email',
        type: 'input',
        span: 12,
        labelWidth: '120px',
      },
      {
        label: '身份证',
        key: 'cardNo',
        type: 'input',
        span: 12,
        labelWidth: '120px',
      },
      {
        label: '性别',
        key: 'sex',
        type: 'radio',
        span: 12,
        labelWidth: '120px',
        options: [
          {
            label: '男',
            value: 1,
          },
          {
            label: '女',
            value: 0,
          },
        ],
      },
      // {
      //   label: '所属岗位',
      //   key: 'positionNames',
      //   type: 'inputButton',
      //   span: 24,
      //   labelWidth: '120px',
      //   disabled: true,
      //   buttonLabel: '选择岗位',
      // },
      // {
      //   label: '所属组织',
      //   key: 'orgNames',
      //   type: 'inputButton',
      //   span: 24,
      //   labelWidth: '120px',
      //   disabled: true,
      //   buttonLabel: '选择组织',
      // },
    ],
    userFormRules: {
      name: [
        {
          required: true,
          message: '请输入用户姓名',
          trigger: 'blur',
        },
      ],
      loginId: [
        {
          required: true,
          message: '请输入登录账号',
          trigger: 'blur',
        },
      ],
      phone: [
        {
          required: true,
          message: '请输入由11位数字组成的手机号',
          trigger: 'blur',
          pattern: /^1(3\d|4[5-9]|5[0-35-9]|6[2567]|7[0-8]|8\d|9[0-35-9])\d{8}$/,
        },
      ],
      email: [
        {
          required: true,
          message: '请输入正确格式的电子邮箱',
          trigger: 'blur',
          pattern: /^([a-zA-Z]|[0-9])(\w|-)+@[a-zA-Z0-9]+\.([a-zA-Z]{2,4})$/,
        },
      ],
      cardNo: [
        {
          message: '请输入由18位数字或x组成的身份证',
          trigger: 'blur',
          pattern:
            /(^[1-9]\d{7}((0\d)|(1[0-2]))(([0|1|2]\d)|3[0-1])\d{3}$)|(^[1-9]\d{5}[1-9]\d{3}((0\d)|(1[0-2]))(([0|1|2]\d)|3[0-1])((\d{4})|\d{3}[Xx])$)/,
        },
      ],
      sex: [
        {
          required: true,
          message: '请选择性别',
          trigger: 'change',
        },
      ],
      orgNames: {
        required: true,
        message: '请选择组织',
        trigger: 'input',
      },
    },
    migrationFormRules: {
      target: [
        {
          required: true,
          message: '请选择转入组织',
          trigger: 'change',
        },
      ],
    },
    migrationFormOptionList: [
      {
        label: '转入组织',
        key: 'target',
        type: 'cascader',
        span: 12,
        labelWidth: '120px',
        options: organizeTreeOptions as any,
        placeholder: ' ',
        cascaderProps: {
          checkStrictly: true,
          label: 'orgName',
        },
      },
    ],
  });
  // 获取组织架构字典
  const getOrgTypeOptions = async () => {
    const codeList = [{ code: 'orgType', prop: 'orgType' }];
    const options = await getDictInfo(codeList);
    optionsState.orgTypeOptions = options.orgType;
  };

  // 获取行政区域字典
  const getDistrictIdOptions = async () => {
    getDistrict().then((res) => {
      const { data } = res;
      optionsState.districtIdOptions = data;
    });
  };

  // 请求下拉列表选项
  const initOptions = async () => {
    getOrgTypeOptions();
    getDistrictIdOptions();
  };

  const setOrganizeTreeOptions = (val: any) => {
    optionsState.organizeTreeOptions = val;
  };

  return {
    ...toRefs(state),
    setOrganizeTreeOptions,
    initOptions,
  };
}
