import { toRefs, reactive, nextTick } from 'vue';
import { ElMessage } from 'element-plus';
import { getOrgAll } from '@/api/permission/organization';
import useOptions from './data';
import { personMagration } from '@/api/permission/userManagement';

const { migrationFormRules, migrationFormOptionList, setOrganizeTreeOptions } = useOptions();

export default function useMigrateOrganization(props: any): any {
  const state = reactive<{
    migrationDialogVisible: boolean;
    migrationFormValue: any;
    migrationFormRef: any;
    migrationLoading: boolean;
  }>({
    migrationDialogVisible: false,
    migrationFormValue: null,
    migrationFormRef: null,
    migrationLoading: false,
  });

  // 打开组织人员迁移弹框
  const handlePersonMigration = () => {
    state.migrationDialogVisible = true;
    getOrgAll().then((res: any) => {
      function handleData(data: any[]) {
        if (data.length) {
          return data.map((item) => {
            item.label = item.orgName;
            item.value = `${item.orgName}&&&${item.id}`;
            if (item.children?.length) {
              item.children = handleData(item.children);
            }
            return item;
          });
        } else {
          return [];
        }
      }
      if (res.data.length) {
        const treeData = res.data;
        setOrganizeTreeOptions(handleData(treeData));
      }
    });
  };

  // 取消迁移
  const handleCancelMigrate = () => {
    state.migrationFormValue = null;
    state.migrationDialogVisible = false;
    nextTick(() => {
      state.migrationFormRef.restoreForm();
    });
  };

  /**
   *
   * @param userList 要迁移的列表
   * @param initData
   */
  const handleMigrate = (userList: any[], initData: any) => {
    state.migrationFormRef.getValue().then((res: any) => {
      if (res) {
        const { target } = res;
        const migrationData = {
          targetOrgName: target[target.length - 1].split('&&&')[0],
          targetOrgId: target[target.length - 1].split('&&&')[1],
          originalOrgName: props.currentOrganizeData.orgName,
          originalOrgId: props.currentOrganizeData.id,
          userIds: userList.map((e) => e.id),
        };
        if (migrationData.targetOrgId !== migrationData.originalOrgId) {
          state.migrationLoading = true;
          personMagration(migrationData)
            .then((res: any) => {
              if (res.code === '0000') {
                state.migrationDialogVisible = false;
                initData();
              }
            })
            .finally(() => {
              state.migrationLoading = false;
            });
        } else {
          ElMessage.warning('请选择与转出组织不同的组织！');
        }
      }
    });
  };

  return {
    ...toRefs(state),
    migrationFormRules,
    migrationFormOptionList,
    handlePersonMigration,
    handleCancelMigrate,
    handleMigrate,
  };
}
