import { toRefs, reactive, watch } from 'vue';
import type { FilterNodeMethodFunction } from 'element-plus/lib/components/tree/src/tree.type';
import { getOrgAll } from '@/api/permission/organization';
import { getUserOrg, userAndOrg, deleteUserAndOrg } from '@/api/permission/userManagement';

interface NodKeys {
  child: any[];
  fatherL: string[];
  fatherLList: any[];
  fatherR: string[];
}
export default function useRelationOrga(): any {
  const state = reactive<{
    relationOrgaDialogVisible: boolean;
    editData: any;
    postData: any;
    relatedPost: any[];
    selectTreeSearchValue: string;
    relationTreeSearchValue: string;
    selectTreeRef: any;
    relationTreeRef: any;
    selectTreeData: any;
    relationTreeData: any;
    nodKeys: NodKeys;
    expandKeysL: string[];
    expandKeysR: string[];
    checkedKeysL: string[];
    checkedKeysR: string[];
    treeDataShow: any;
    currentData: any;
  }>({
    relationOrgaDialogVisible: false,
    editData: null,
    postData: [],
    relatedPost: [],
    selectTreeSearchValue: '',
    relationTreeSearchValue: '',
    selectTreeRef: null,
    relationTreeRef: null,
    selectTreeData: [],
    relationTreeData: [],
    nodKeys: {
      // 所有子节点，左右的所有父节点
      child: [],
      fatherLList: [],
      fatherL: [],
      fatherR: [],
    },
    expandKeysL: [], // 控制可选关联展开keys集合
    expandKeysR: [], // 控制已关联展开keys集合
    checkedKeysL: [], // 控制可选关联勾选keys集合
    checkedKeysR: [], // 控制已关联勾选keys集合
    treeDataShow: {
      left: null,
      right: null,
    },
    currentData: null,
  });

  const defaultProps = {
    children: 'children',
    label: 'title',
    disabled: 'disabled',
  };
  // 处理树数据
  const handleTreeData = () => {
    const fatherKeysL: string[] = [];
    const fatherLList: any[] = [];
    const fatherKeysR: string[] = [];
    const childKeys: any[] = [];

    function leftFun(data: any) {
      return data.map((item: any) => {
        const obj: any = {
          title: item.orgName,
          key: item.id,
          disabled: state.relationTreeData.includes(item.id),
        };
        if (item.children?.length) {
          const arr = leftFun(item.children).filter((el: any) => el);
          if (arr.length) {
            fatherKeysL.push(item.id);
            fatherLList.push(item);
            obj.children = arr;
            return obj;
          } else return null;
        } else {
          childKeys.push(item);
          // if (state.relationTreeData.includes(item.id)) return null;
          // else return obj;
          return obj;
        }
      });
    }

    function rightFun(data: any) {
      const rightDataList: any[] = [];
      const f = (data) => {
        data.forEach((item: any) => {
          const obj: any = {
            title: item.orgName,
            key: item.id,
          };
          if (state.relationTreeData.includes(item.id)) {
            rightDataList.push(obj);
          }
          if (item.children?.length) {
            f(item.children);
          }

          // if (item.children?.length) {
          //   const arr = f(item.children).filter((el: any) => el);
          //   if (arr.length) {
          //     fatherKeysR.push(item.id);
          //     obj.children = arr;
          //     return obj;
          //   } else return null;
          // } else if (state.relationTreeData.includes(item.id)) {
          //   console.log('right', obj);
          //   return obj;
          // } else return null;
        });
      };
      f(data);
      return rightDataList;
    }
    if (state.selectTreeData.length) {
      const left = leftFun(state.selectTreeData).filter((el: any) => el);
      const right = state.relationTreeData.length
        ? rightFun(state.selectTreeData).filter((el: any) => el)
        : [];
      state.nodKeys.fatherL = fatherKeysL;
      state.nodKeys.fatherLList = fatherLList;
      state.nodKeys.fatherR = fatherKeysR;
      state.nodKeys.child = childKeys;
      if (state.expandKeysL.length) {
        const expand = fatherKeysL.filter((el) => state.expandKeysL.includes(el));
        state.expandKeysL = expand;
      }
      if (state.expandKeysR.length) {
        const expand = fatherKeysR.filter((el) => state.expandKeysR.includes(el));
        state.expandKeysR = expand;
      }
      if (state.checkedKeysR.length) {
        state.checkedKeysL = [];
      }
      if (state.checkedKeysL.length) {
        state.checkedKeysR = [];
      }
      state.treeDataShow = { left, right };
    } else {
      state.treeDataShow = { left: [], right: [] };
    }
  };

  // 获取可选资源树数据
  const handleGetMenu = async () => {
    await getOrgAll().then((res) => {
      state.selectTreeData = res.data;
      handleTreeData();
    });
  };
  // 获取已关联资源树数据
  const handleGeLowestMenus = () => {
    getUserOrg(state.currentData.id).then((res) => {
      state.relationTreeData = res.data?.map((e: any) => e.id);
      handleTreeData();
    });
  };

  // 跳转到关联组织tab
  const handleChangeOrgTab = async (row) => {
    state.currentData = row;
    state.relationTreeData = state.currentData.orgId;
    await handleGetMenu();
  };

  // 打开关联弹框
  const handleOpenOrgaDialog = (row: any) => {
    state.currentData = row;
    state.relationOrgaDialogVisible = true;
    state.relationTreeData = state.currentData.orgId;
    handleGetMenu();
    // handleGeLowestMenus();
  };
  // 关闭资源框
  const handlecloseOrgaDialog = () => {
    state.relationOrgaDialogVisible = false;
  };

  /**
   * 过滤树数据
   */
  watch(
    () => state.selectTreeSearchValue,
    (curAge) => {
      state.selectTreeRef?.filter(curAge);
    },
  );
  watch(
    () => state.relationTreeSearchValue,
    (curAge) => {
      state.relationTreeRef?.filter(curAge);
    },
  );
  const filterNode: FilterNodeMethodFunction = (value, data) => {
    if (!value) return true;
    return data.title.indexOf(value) !== -1;
  };

  // 展开回调
  const onExpand = (data: any, type: string) => {
    if (type === 'left') {
      state.expandKeysL.push(data.key);
    }
    if (type === 'right') {
      state.expandKeysR.push(data.key);
    }
  };

  // 折叠回调
  const onCollapse = (data: any, type: string) => {
    if (type === 'left') {
      const index = state.expandKeysL.findIndex((item) => item === data.key);
      if (index !== -1) {
        state.expandKeysL.splice(index, 1);
      }
    }
    if (type === 'right') {
      const index = state.expandKeysR.findIndex((item) => item === data.key);
      if (index !== -1) {
        state.expandKeysR.splice(index, 1);
      }
    }
  };

  // 选择节点回调
  const onChangeCurrent = (data: any, type: string) => {
    if (type === 'left') {
      state.checkedKeysL = state.selectTreeRef.getCheckedKeys();
    }
    if (type === 'right') {
      state.checkedKeysR = state.relationTreeRef.getCheckedKeys();
    }
  };

  // 关联资源
  const handleRelation = () => {
    const menuObj = state.nodKeys.child
      .concat(state.nodKeys.fatherLList)
      .filter((item) => state.checkedKeysL.includes(item.id));
    // 选中并添加的资源数据
    // const addTreeData = menuObj.map((el) => el.id);
    state.relationTreeData = state.relationTreeData.concat(state.checkedKeysL);
    const org = menuObj.map((el) => ({
      orgId: el.id,
      orgName: el.orgName,
    }));
    handleTreeData();
    // return;
    const params = {
      userId: state.currentData.id,
      userName: state.currentData.name,
      org,
    };
    userAndOrg(params).then(() => {
      handleGeLowestMenus();
    });
  };

  // 取消关联资源
  const handleCancelRelation = () => {
    const menuObj = state.nodKeys.child
      .concat(state.nodKeys.fatherLList)
      .filter((item) => state.checkedKeysR.includes(item.id));
    // 选中要移除的资源
    const removeTreeData = menuObj.map((el) => el.id);
    const org = menuObj.map((el) => ({
      orgId: el.id,
      orgName: el.orgName,
    }));
    state.relationTreeData = state.relationTreeData.filter(
      (item) => !removeTreeData.includes(item),
    );
    handleTreeData();
    // return;
    const params = {
      userId: state.currentData.id,
      userName: state.currentData.name,
      org,
    };
    deleteUserAndOrg(params).then(() => {
      handleGeLowestMenus();
    });
  };

  // 全部展开/收缩
  const expandAll = (ref: any, isExpand: boolean) => {
    for (let i = 0; i < ref.store._getAllNodes().length; i++) {
      ref.store._getAllNodes()[i].expanded = isExpand;
    }
  };

  return {
    ...toRefs(state),
    expandAll,
    filterNode,
    handleOpenOrgaDialog,
    handlecloseOrgaDialog,
    defaultProps,
    onExpand,
    onCollapse,
    onChangeCurrent,
    handleRelation,
    handleCancelRelation,
    handleChangeOrgTab,
  };
}
