import { toRefs, reactive, computed } from 'vue';
import type { AxiosResponse } from 'axios';
import { getPostList } from '@/api/permission/postManagement';
import { deleteUserAndPost, userAndPost } from '@/api/permission/userManagement';

export default function useRelationPost(): any {
  const state = reactive<{
    relationPostDialogVisible: boolean;
    editData: any;
    postData: any;
    relatedPost: any[];
  }>({
    relationPostDialogVisible: false,
    editData: null,
    postData: [],
    relatedPost: [],
  });

  const relatedPostId = computed(() => state.relatedPost.map((el: any) => el.id));
  const relatedPostName = computed(() => state.relatedPost.map((el: any) => el.positionName));

  const relationPostRender = (h: any, option: any) => h('span', null, option.positionName);

  const relationPostProps = {
    key: 'id',
    label: 'positionName',
    disabled: 'disabled',
  };
  const relationPostTitles: [string, string] = ['可选岗位', '已关联岗位'];

  // tab切换到关联岗位页面
  const tabClickPost = (row) => {
    state.editData = row;
    const relatedPostId = row.value.positionId ? row.value.positionId : [];
    getPostList().then((res) => {
      state.postData = res.data;
      state.relatedPost = state.postData.filter((item: any) => relatedPostId.includes(item.id));
    });
  };

  // 打开关联岗位弹框
  const handleOpenPostDialog = (row: any) => {
    state.editData = row;
    state.relationPostDialogVisible = true;
    const relatedPostId = row.positionId ? row.positionId : [];
    getPostList().then((res) => {
      state.postData = res.data;
      state.relatedPost = state.postData.filter((item: any) => relatedPostId.includes(item.id));
    });
  };
  // 关闭关联岗位弹框
  const handleClosePostDialog = () => {
    state.relationPostDialogVisible = false;
  };

  /**
   * 关联用户
   * @param targetKeys 当前值
   * @param direction 方向
   * @param moveKeys 发生移动的数据 key 数组
   * @param cb 完成后的回调
   */
  const handleChangeRelationPost = (targetKeys: any, direction: any, moveKeys: any) => {
    let requestApi: (param) => Promise<AxiosResponse>;
    let arr: any = [];
    if (direction === 'right') {
      arr = state.postData.filter((item: any) => moveKeys.includes(item.id));
      state.relatedPost = state.relatedPost.concat(arr);
      requestApi = userAndPost;
    }
    if (direction === 'left') {
      arr = state.relatedPost.filter((item: any) => !moveKeys.includes(item.id));
      state.relatedPost = arr;
      requestApi = deleteUserAndPost;
    }
    // cb();
    const positions = arr.map((item: any) => ({
      positionId: item.id,
      positionName: item.positionName,
    }));
    const param = {
      userId: state.editData.id,
      positions,
    };
    requestApi!(param).then(() => {
      if (direction === 'left') {
        const ids = arr.map((el: any) => el.id);
        state.relatedPost = state.relatedPost.filter((el: any) => !ids.includes(el.id));
      } else if (direction === 'right') {
        state.relatedPost = state.relatedPost.concat(arr);
      }
    });
  };

  return {
    ...toRefs(state),
    handleOpenPostDialog,
    handleClosePostDialog,
    relationPostRender,
    relationPostProps,
    relationPostTitles,
    relatedPostId,
    relatedPostName,
    handleChangeRelationPost,
    tabClickPost,
  };
}
