import { toRefs, reactive, computed } from 'vue';
import type { AxiosResponse } from 'axios';

import { getAllRole, updateUserRole } from '@/api/permission/roleManagement';
import { getUserRole, deleteUserAndRole, userAndRole } from '@/api/permission/userManagement';

const state = reactive<{
  relationRoleDialogVisible: boolean;
  editData: any;
  roleData: any[];
  relatedRole: any[];
  relationEditData: any;
}>({
  relationRoleDialogVisible: false,
  editData: null,
  roleData: [],
  relatedRole: [],
  relationEditData: { id: null },
});
export default function useRelationRole(): any {
  const relatedRoleId = computed(() => state.relatedRole.map((el: any) => el.id));

  const relationRoleRender = (h: any, option: any) => h('span', null, option.roleName);

  const relationRoleProps = {
    key: 'id',
    label: 'roleName',
    disabled: 'disabled',
  };
  const relationRoleTitles: [string, string] = ['可选角色', '已关联角色'];

  // 获取用户关联角色
  const getUserRoleData = (row: any) => {
    state.editData = row;
    getAllRole({ filterGroup: true }).then((res) => {
      state.roleData = res.data;
    });
    getUserRole(row.id).then((res) => {
      state.relatedRole = res.data;
    });
  };

  // 打开关联角色弹框
  const handleOpenRoleDialog = (row: any) => {
    state.relationRoleDialogVisible = true;
    state.relationEditData = row;
    getUserRoleData(row);
  };

  // 关闭关联角色弹框
  const handleCloseRoleDialog = () => {
    state.relationRoleDialogVisible = false;
    state.roleData = [];
    state.relatedRole = [];
  };

  /**
   * 关联用户
   * @param targetKeys 当前值
   * @param direction 方向
   * @param moveKeys 发生移动的数据 key 数组
   */
  const handleChangeRelationRole = async (
    targetKeys: any,
    direction: any,
    moveKeys: any,
    cb: any,
  ) => {
    let requestApi: (param) => Promise<AxiosResponse>;
    let arr: any = [];
    if (direction === 'right') {
      arr = state.roleData.filter((item: any) => moveKeys.includes(item.id));
      state.relatedRole = state.relatedRole.concat(arr);
      requestApi = userAndRole;
    }
    if (direction === 'left') {
      arr = state.relatedRole.filter((item: any) => moveKeys.includes(item.id));
      const ids = arr.map((el: any) => el.id);
      state.relatedRole = state.relatedRole.filter((el: any) => !ids.includes(el.id));
      requestApi = deleteUserAndRole;
    }
    const roleIds = arr.map((item: any) => ({
      roleId: item.id,
      roleName: item.roleName,
    }));
    const param = {
      userId: state.editData.id,
      userName: state.editData.name,
      roleIds,
    };
    try {
      await requestApi!(param);
      cb();
    } catch (err) {
      getUserRoleData(state.editData);
    }

    // requestApi!(param).then(() => {
    //   if (direction === 'left') {
    //     const ids = arr.map((el: any) => el.id);
    //     state.relatedRole = state.relatedRole.filter((el: any) => !ids.includes(el.id));
    //   } else if (direction === 'right') {
    //     state.relatedRole = state.relatedRole.concat(arr);
    //   }
    // });
  };
  /**
   * 更新用户关联角色
   */
  const handleUpdateRelationRole = (closeInfo: any, userName: string) => {
    const roleIds = state.relatedRole.map((item: any) => ({
      roleId: item.id,
      roleName: item.roleName,
    }));
    const param = {
      userId: state.editData.id,
      userName: state.editData?.name ? state.editData?.name : userName,
      roleIds,
    };
    updateUserRole(param).then(() => {
      if (closeInfo) {
        closeInfo();
      } else {
        handleCloseRoleDialog();
      }
    });
  };

  return {
    ...toRefs(state),
    handleOpenRoleDialog,
    handleCloseRoleDialog,
    relatedRoleId,
    relationRoleRender,
    relationRoleProps,
    relationRoleTitles,
    handleChangeRelationRole,
    getUserRoleData,
    handleUpdateRelationRole,
  };
}
