import { toRefs, onMounted, reactive } from 'vue';
import type { FormItemRule } from 'element-plus/es/tokens/form.d';
import type { FormOption, SearchOption, FormSelectOption } from '@/types/tools';
import { getDictInfo } from '@/utils/tools';

export default function useOptions(): any {
  const optionsState = reactive<{
    levelOptions: FormSelectOption[];
  }>({
    levelOptions: [],
  });
  const { levelOptions } = toRefs(optionsState);
  const state = reactive<{
    searchOptions: SearchOption[];
    columns: any[];
    formOptionList: FormOption[];
    formRules: Partial<Record<string, FormItemRule | FormItemRule[]>>;
  }>({
    searchOptions: [
      {
        label: '行政区级别',
        key: 'level',
        type: 'select',
        options: levelOptions as unknown as FormSelectOption[],
        clearable: true,
        span: 5,
      },
      {
        label: '',
        key: 'keyword',
        type: 'text',
        placeholder: '行政区名/行政区代码/简称',
        span: 6,
        labelWidth: '0px',
      },
    ],
    columns: [
      { prop: 'code', label: '行政区代码', minWidth: 100 },
      { prop: 'name', label: '行政区名', minWidth: 100 },
      { prop: 'simpleName', label: '行政区简称', minWidth: 100 },
      { prop: 'levelName', label: '行政区级别', minWidth: 100 },
      { prop: 'labelCode', label: '内部标识码', minWidth: 100 },
      { prop: 'sort', label: '排序值', minWidth: 100 },
    ],
    formOptionList: [
      {
        label: '行政区代码',
        key: 'code',
        type: 'input',
        span: 12,
        labelWidth: '120px',
        maxlength: 50,
      },
      {
        label: '行政区名',
        key: 'name',
        type: 'input',
        span: 12,
        labelWidth: '120px',
        maxlength: 50,
      },
      {
        label: '行政区简称',
        key: 'simpleName',
        type: 'input',
        span: 12,
        labelWidth: '120px',
        maxlength: 10,
      },

      {
        label: '行政区级别',
        key: 'level',
        type: 'select',
        options: levelOptions as unknown as FormSelectOption[],
        span: 12,
        labelWidth: '120px',
      },
      {
        label: '内部标识码',
        key: 'labelCode',
        type: 'input',
        span: 12,
        labelWidth: '120px',
      },
      {
        label: '排序值',
        key: 'sort',
        type: 'inputNumber',
        span: 12,
        labelWidth: '120px',
        value: 1,
        min: 1,
      },
    ],
    formRules: {
      code: [
        {
          required: true,
          message: '请输入行政区代码',
          trigger: 'blur',
        },
      ],
      name: [
        {
          required: true,
          message: '请输入行政区名',
          trigger: 'blur',
        },
      ],
      simpleName: [
        {
          message: '请输入行政区简称',
          trigger: 'change',
        },
      ],
      level: [
        {
          required: true,
          message: '请输入行政区级别',
          trigger: 'change',
        },
      ],
      labelCode: [
        {
          required: true,
          message: '请输入内部标识码',
          trigger: 'blur',
        },
      ],
      sort: [
        {
          required: true,
          message: '请输入排序值',
          trigger: 'blur',
        },
      ],
    },
  });

  const getLevelOptions = async () => {
    const codeList = [{ code: '0005', prop: 'typeOption' }];
    const options = await getDictInfo(codeList);
    optionsState.levelOptions = options.typeOption;
  };

  // 请求下拉列表选项
  const initOptions = async () => {
    getLevelOptions();
  };

  onMounted(async () => {
    initOptions();
  });

  return {
    ...toRefs(state),
  };
}
