import { toRefs, reactive, nextTick, computed } from 'vue';
import { addDistrict, updateDistrict } from '@/api/systemManagement/administrativeRegion';

export default function useEditAdministrativeRegion(): any {
  const state = reactive<{
    dialogVisible: boolean;
    formValue: any;
    formDisabled: boolean;
    dialogType: string;
    formRef: any;
    saveLoading: boolean;
    editData: any;
  }>({
    dialogVisible: false,
    formValue: null,
    formDisabled: false,
    dialogType: '',
    formRef: null,
    saveLoading: false,
    editData: null,
  });

  // 取消编辑
  const handleCancel = () => {
    state.formValue = null;
    state.dialogVisible = false;
    nextTick(() => {
      state.formRef.restoreForm();
    });
  };
  // 新增、编辑行政区域
  const handleOpenDialog = (type: string, data: any = null) => {
    state.dialogVisible = true;
    state.dialogType = type;
    switch (type) {
      case 'add':
        state.formDisabled = false;
        break;
      case 'edit':
        state.editData = data;
        state.formValue = data;
        state.formDisabled = true;
        break;
      case 'addChild':
        state.editData = data;
        state.formValue = { pid: data.id };
        state.formDisabled = false;
        break;
      default:
        break;
    }
  };

  const dialogTitle = computed(() => {
    if (state.dialogType === 'add') {
      return '行政区新增';
    } else if (state.dialogType === 'edit') {
      return '行政区信息';
    } else {
      return '新增子项';
    }
  });

  // 保存行政区域
  const handleSave = (initData: () => void) => {
    if (state.dialogType === 'edit' && state.formDisabled) {
      state.formDisabled = false;
      return;
    }
    state.formRef.getValue().then((res: any) => {
      if (res) {
        state.saveLoading = true;
        if (state.dialogType === 'add') {
          res.pid = '-1';
        } else if (state.dialogType === 'edit') {
          res.id = state.editData.id;
          res.pid = state.editData.pid;
        } else if (state.dialogType === 'addChild') {
          res.pid = state.editData.id;
        }
        const _api =
          (['add', 'addChild'].includes(state.dialogType) && addDistrict) || updateDistrict;
        _api(res)
          .then(() => {
            state.dialogVisible = false;
            initData();
          })
          .finally(() => {
            state.saveLoading = false;
          });
      }
    });
  };

  return {
    ...toRefs(state),
    handleCancel,
    handleOpenDialog,
    handleSave,
    dialogTitle,
  };
}
