import { toRefs, reactive, onMounted } from 'vue';
import { ElMessage } from 'element-plus';
import { checkPermission } from '@/utils/tools';

import { getDictionaryList } from '@/api/systemManagement/dictionaryManagement';

export default function useQueryTypeList(): any {
  const state = reactive<{
    typeSearchValue: string;
    activeItemData: any;
    dictionaryList: any[];
  }>({
    typeSearchValue: '',
    activeItemData: null,
    dictionaryList: [],
  });

  // 查询字典类型列表
  const getDictionaryTypeList = (params = {}) => {
    getDictionaryList(params).then((_res) => {
      const treeData = [
        { label: '系统类型', id: 1, isParent: true, children: _res.data.systemList },
        { label: '业务类型', id: 0, isParent: true, children: _res.data.businessList },
      ];
      state.dictionaryList = treeData;
      [state.activeItemData] = _res.data.systemList;
      // if (!state.activeItemData) {
      //   [state.activeItemData] = _res.data;
      // }
    });
  };

  // 选择字典类型
  const selectDictionaryType = (data) => {
    if (data.id === state.activeItemData.id) return;
    state.activeItemData = data;
  };

  // 搜索字典类型
  const searchDictionaryType = () => {
    if (state.typeSearchValue.trim() === '' && state.typeSearchValue !== '') {
      return;
    }
    getDictionaryTypeList({ keyword: state.typeSearchValue });
  };

  onMounted(() => {
    if (checkPermission('sys_dict_type_list')) {
      getDictionaryTypeList();
    } else {
      ElMessage.warning('暂无权限！');
    }
  });
  return {
    ...toRefs(state),
    selectDictionaryType,
    searchDictionaryType,
  };
}
