import { toRefs, reactive } from 'vue';
import type { FormItemRule } from 'element-plus/es/tokens/form.d';
import type { FormOption, SearchOption } from '@/types/tools';

export default function useOptions(): any {
  const state = reactive<{
    searchOptions: SearchOption[];
    columns: any[];
    formOptionList: FormOption[];
    formRules: Partial<Record<string, FormItemRule | FormItemRule[]>>;
  }>({
    searchOptions: [
      {
        label: '标题',
        key: 'title',
        type: 'text',
      },
      {
        label: '发布时间',
        key: 'sendTime',
        type: 'dateTimePicker',
        datePickerType: 'datetimerange',
      },
    ],
    columns: [
      {
        prop: 'title',
        label: '标题',
        minWidth: 80,
        align: 'center',
      },
      {
        prop: 'content',
        label: '内容',
        minWidth: 100,
        align: 'center',
        showTooltip: true,
      },
      {
        prop: 'attachments',
        label: '附件',
        minWidth: 100,
        align: 'center',
        slot: 'attachments',
      },
      {
        prop: 'sendTime',
        label: '发布时间',
        minWidth: 80,
        align: 'center',
      },
      {
        prop: 'isDraftName',
        label: '发布状态',
        minWidth: 80,
        align: 'center',
        slot: 'publishType',
      },
    ],
    formOptionList: [
      {
        label: '标题',
        key: 'title',
        type: 'input',
        span: 18,
        labelWidth: '120px',
        maxlength: 20,
      },
      {
        label: '内容',
        key: 'content',
        type: 'input',
        inputType: 'textarea',
        rows: '4',
        span: 24,
        labelWidth: '120px',
        maxlength: 200,
      },
      {
        label: '截止日期',
        key: 'validity',
        type: 'dateTimePicker',
        datePickerType: 'date',
        span: 16,
        labelWidth: '120px',
        disabledDate: (time: Date) => time.getTime() < Date.now() - 3600 * 1000 * 24,
      },
      {
        label: '附件上传',
        key: 'attachments',
        type: 'attachmentInput',
        span: 24,
        labelWidth: '120px',
      },
    ],
    formRules: {
      title: [
        {
          required: true,
          message: '请输入公告标题',
          trigger: 'blur',
        },
      ],
      content: [
        {
          required: true,
          message: '请输入公告内容',
          trigger: 'blur',
        },
      ],
      validity: [
        {
          required: true,
          message: '请选择有效日期',
          trigger: 'blur',
        },
      ],
    },
  });

  return {
    ...toRefs(state),
  };
}
