import { toRefs, reactive } from 'vue';
import type { FormItemRule } from 'element-plus/es/tokens/form.d';
import type { FormOption, SearchOption } from '@/types/tools';

export default function useOptions(): any {
  const state = reactive<{
    searchOptions: SearchOption[];
    columns: any[];
    formOptionList: FormOption[];
    formRules: Partial<Record<string, FormItemRule | FormItemRule[]>>;
  }>({
    searchOptions: [
      {
        label: '标题',
        key: 'title',
        type: 'text',
      },
      {
        label: '发布时间',
        key: 'sendTime',
        type: 'dateTimePicker',
        datePickerType: 'datetimerange',
      },
    ],
    columns: [
      {
        prop: 'title',
        label: '标题',
        minWidth: 80,
        align: 'center',
      },
      {
        prop: 'senderName',
        label: '发送人',
        minWidth: 60,
        align: 'center',
      },
      {
        prop: 'content',
        label: '内容',
        minWidth: 100,
        align: 'center',
      },
      {
        prop: 'attachments',
        label: '附件',
        minWidth: 100,
        align: 'center',
        slot: 'attachments',
      },
      {
        prop: 'sendTime',
        label: '发布时间',
        minWidth: 80,
        align: 'center',
      },
      {
        prop: 'stateName',
        label: '状态',
        minWidth: 80,
        align: 'center',
        slot: 'publishType',
      },
    ],
    formOptionList: [
      {
        label: '标题',
        key: 'title',
        type: 'input',
        span: 18,
        labelWidth: '120px',
      },
      {
        label: '内容',
        key: 'content',
        type: 'input',
        inputType: 'textarea',
        rows: '4',
        span: 24,
        labelWidth: '120px',
      },
      {
        label: '接收方式',
        key: 'receiveMode',
        type: 'checkbox',
        options: [
          { value: '站内', label: '站内' },
          { value: '邮箱', label: '邮箱' },
        ],
        span: 16,
        labelWidth: '120px',
      },
      {
        label: '接收人',
        key: 'receiverNames',
        type: 'PersonTree',
        span: 24,
        labelWidth: '120px',
      },
      {
        label: '附件上传',
        key: 'attachments',
        type: 'attachmentInput',
        span: 24,
        labelWidth: '120px',
      },
    ],
    formRules: {
      title: [
        {
          required: true,
          message: '请输入私信标题',
          trigger: 'blur',
        },
      ],
      content: [
        {
          required: true,
          message: '请输入私信内容',
          trigger: 'blur',
        },
      ],
      receiveMode: [
        {
          required: true,
          message: '请选择接收方式',
          trigger: 'blur',
        },
      ],
      receiverNames: [
        {
          required: true,
          message: '请选择接收人',
          trigger: 'blur',
        },
      ],
    },
  });

  return {
    ...toRefs(state),
  };
}
