import { toRefs, reactive } from 'vue';
import type { SearchOption } from '@/types/tools';

export default function useOptions(): any {
  const optionsData = {
    eventType: [
      {
        value: '0',
        label: '系统事件',
      },
      {
        value: '1',
        label: '业务事件',
      },
    ],
    riskLevel: [
      {
        value: '0',
        label: '高',
      },
      {
        value: '1',
        label: '中',
      },
      {
        value: '2',
        label: '低',
      },
    ],
  };
  const state = reactive<{
    searchOptions: SearchOption[];
    columns: any[];
  }>({
    searchOptions: [
      {
        label: '操作用户',
        key: 'loginId',
        type: 'text',
        span: 4,
      },
      {
        label: '事件类型',
        key: 'eventType',
        type: 'select',
        options: optionsData.eventType,
        span: 4,
      },
      {
        label: '日期',
        key: 'createTime',
        type: 'dateTimePicker',
        datePickerType: 'datetimerange',
        span: 7,
      },
      {
        label: '风险等级',
        key: 'riskLevel',
        type: 'select',
        options: optionsData.riskLevel,
        span: 4,
      },
    ],
    columns: [
      {
        prop: 'loginId',
        label: '操作用户',
        minWidth: 100,
        align: 'center',
      },
      {
        prop: 'ip',
        label: '操作IP',
        minWidth: 100,
        align: 'center',
      },
      {
        prop: 'requestUri',
        label: '请求地址',
        minWidth: 100,
        align: 'center',
      },
      {
        prop: 'param',
        label: '请求参数',
        minWidth: 120,
        align: 'center',
      },
      {
        prop: 'typeName',
        label: '日志类型',
        minWidth: 100,
        align: 'center',
      },
      {
        prop: 'eventTypeName',
        label: '事件类型',
        minWidth: 100,
        align: 'center',
      },
      {
        prop: 'message',
        label: '日志信息',
        minWidth: 100,
        align: 'center',
      },
      {
        prop: 'riskLevelName',
        label: '风险等级',
        minWidth: 100,
        align: 'center',
      },
      {
        prop: 'exception',
        label: '异常信息',
        minWidth: 100,
        align: 'center',
      },
      {
        prop: 'userAgent',
        label: '浏览器标识',
        minWidth: 200,
        align: 'center',
      },
      {
        prop: 'createTime',
        label: '操作时间',
        minWidth: 100,
        align: 'center',
      },
    ],
  });

  return {
    ...toRefs(state),
  };
}
