import { toRefs, reactive } from 'vue';
import type { SearchOption } from '@/types/tools';

export const optionsData = {
  logType: [
    {
      value: '错误',
      label: '错误',
    },
    {
      value: '警告',
      label: '警告',
    },
    {
      value: '信息',
      label: '信息',
    },
  ],
  sourceType: [
    {
      value: 'FRONT_END',
      label: '前端',
    },
    {
      value: 'BACK_END',
      label: '后端',
    },
  ],
};

export default function useOptions() {
  const state = reactive<{
    searchOptions: SearchOption[];
    columns: any[];
  }>({
    searchOptions: [
      {
        label: '日志类别',
        key: 'logLevel',
        type: 'select',
        span: 4,
        options: optionsData.logType,
        clearable: true,
      },
      {
        label: '日志来源',
        key: 'source',
        type: 'select',
        span: 4,
        options: optionsData.sourceType,
        clearable: true,
      },
      {
        label: '',
        key: 'createTime',
        type: 'dateTimePicker',
        datePickerType: 'datetimerange',
        span: 7,
      },
      {
        label: '',
        key: 'keyword',
        type: 'text',
        span: 4,
        placeholder: '操作目标/日志信息',
      },
    ],
    columns: [
      {
        prop: 'logLevel',
        label: '日志类别',
        minWidth: 50,
        align: 'center',
      },
      {
        prop: 'server',
        label: '服务器',
        minWidth: 100,
        align: 'center',
      },
      {
        prop: 'browser',
        label: '浏览器',
        minWidth: 100,
        align: 'center',
      },
      {
        prop: 'target',
        label: '操作目标',
        minWidth: 100,
        align: 'center',
      },
      {
        prop: 'content',
        label: '日志信息',
        minWidth: 100,
        align: 'center',
        slot: 'content',
      },
      {
        prop: 'source',
        label: '日志来源',
        minWidth: 40,
        align: 'center',
        slot: 'source',
      },
      {
        prop: 'dateTime',
        label: '操作时间',
        minWidth: 70,
        align: 'center',
      },
    ],
  });

  return {
    ...toRefs(state),
  };
}
