import { UserConfigExport, ConfigEnv, loadEnv } from 'vite';
import { wrapperEnv, createProxy } from './build/utils';
import { resolve } from 'path';
import { createVitePlugins } from './build/vite/plugin';
import externalGlobals from 'rollup-plugin-external-globals';

const pathResolve = (dir: string): any => resolve(__dirname, '.', dir);
const alias: Record<string, string> = {
  '@': pathResolve('src'),
  '/mock': pathResolve('mock'),
};

const buildOutDir = (mode: string) => {
  switch (mode) {
    case 'dev':
      return 'smartweb-v2-dev';
    default:
      return 'smartweb-v2';
  }
};

export default ({ command, mode }: ConfigEnv): UserConfigExport => {
  const root = process.cwd();
  const isBuild = command === 'build'; // 是否是打包命令
  const env = loadEnv(mode, root);
  // 转换所有环境变量中的变量类型
  const viteEnv = wrapperEnv(env);
  const { VITE_PORT, VITE_PROXY } = viteEnv;

  return {
    root,
    server: {
      host: true,
      port: VITE_PORT,
      proxy: createProxy(VITE_PROXY),
    },
    resolve: {
      alias,
    },
    //  插件配置
    plugins: createVitePlugins(viteEnv, isBuild, mode),
    build: {
      outDir: buildOutDir(mode),
      manifest: true,
      rollupOptions: {
        plugins: [
          externalGlobals({
            '@smart/cesium': 'Cesium',
            smart3d: 'smart3d',
          }),
        ],
        output: {
          manualChunks: {
            'element-plus': ['element-plus'],
          },
        },
      },
      chunkSizeWarningLimit: 600,
    },
    base: '',
  };
};
